/*
 * This was automagically generated from arch/arm/tools/mach-types!
 * Do NOT edit
 */

#ifndef __ASM_ARM_MACH_TYPE_H
#define __ASM_ARM_MACH_TYPE_H

#ifndef __ASSEMBLY__
/* The type of machine we're running on */
extern unsigned int __machine_arch_type;
#endif

/* see arch/arm/kernel/arch.c for a description of these */
#define MACH_TYPE_EBSA110              0
#define MACH_TYPE_RISCPC               1
#define MACH_TYPE_EBSA285              4
#define MACH_TYPE_NETWINDER            5
#define MACH_TYPE_CATS                 6
#define MACH_TYPE_SHARK                15
#define MACH_TYPE_BRUTUS               16
#define MACH_TYPE_PERSONAL_SERVER      17
#define MACH_TYPE_L7200                19
#define MACH_TYPE_PLEB                 20
#define MACH_TYPE_INTEGRATOR           21
#define MACH_TYPE_H3600                22
#define MACH_TYPE_P720T                24
#define MACH_TYPE_ASSABET              25
#define MACH_TYPE_LART                 27
#define MACH_TYPE_GRAPHICSCLIENT       29
#define MACH_TYPE_XP860                30
#define MACH_TYPE_CERF                 31
#define MACH_TYPE_NANOENGINE           32
#define MACH_TYPE_JORNADA720           48
#define MACH_TYPE_EDB7211              50
#define MACH_TYPE_PFS168               52
#define MACH_TYPE_FLEXANET             54
#define MACH_TYPE_SIMPAD               87
#define MACH_TYPE_LUBBOCK              89
#define MACH_TYPE_CLEP7212             91
#define MACH_TYPE_SHANNON              97
#define MACH_TYPE_CONSUS               105
#define MACH_TYPE_AAED2000             106
#define MACH_TYPE_CDB89712             107
#define MACH_TYPE_GRAPHICSMASTER       108
#define MACH_TYPE_ADSBITSY             109
#define MACH_TYPE_PXA_IDP              110
#define MACH_TYPE_PT_SYSTEM3           112
#define MACH_TYPE_AUTCPU12             118
#define MACH_TYPE_H3100                136
#define MACH_TYPE_COLLIE               146
#define MACH_TYPE_BADGE4               148
#define MACH_TYPE_FORTUNET             152
#define MACH_TYPE_MX1ADS               160
#define MACH_TYPE_H7201                161
#define MACH_TYPE_H7202                162
#define MACH_TYPE_IQ80321              169
#define MACH_TYPE_KS8695               180
#define MACH_TYPE_SMDK2410             193
#define MACH_TYPE_CEIVA                200
#define MACH_TYPE_VOICEBLUE            218
#define MACH_TYPE_H5400                220
#define MACH_TYPE_OMAP_INNOVATOR       234
#define MACH_TYPE_IXDP2400             242
#define MACH_TYPE_IXDP2800             243
#define MACH_TYPE_IXDP425              245
#define MACH_TYPE_HACKKIT              254
#define MACH_TYPE_IXCDP1100            260
#define MACH_TYPE_AT91RM9200DK         262
#define MACH_TYPE_CINTEGRATOR          275
#define MACH_TYPE_VIPER                283
#define MACH_TYPE_ADI_COYOTE           290
#define MACH_TYPE_IXDP2401             299
#define MACH_TYPE_IXDP2801             300
#define MACH_TYPE_IQ31244              327
#define MACH_TYPE_BAST                 331
#define MACH_TYPE_H1940                347
#define MACH_TYPE_ENP2611              356
#define MACH_TYPE_S3C2440              362
#define MACH_TYPE_GUMSTIX              373
#define MACH_TYPE_OMAP_H2              382
#define MACH_TYPE_E740                 384
#define MACH_TYPE_IQ80331              385
#define MACH_TYPE_VERSATILE_PB         387
#define MACH_TYPE_KEV7A400             388
#define MACH_TYPE_LPD7A400             389
#define MACH_TYPE_LPD7A404             390
#define MACH_TYPE_CSB337               399
#define MACH_TYPE_MAINSTONE            406
#define MACH_TYPE_LITE300              408
#define MACH_TYPE_XCEP                 413
#define MACH_TYPE_ARCOM_VULCAN         414
#define MACH_TYPE_NOMADIK              420
#define MACH_TYPE_CORGI                423
#define MACH_TYPE_POODLE               424
#define MACH_TYPE_ARMCORE              438
#define MACH_TYPE_MX31ADS              447
#define MACH_TYPE_HIMALAYA             448
#define MACH_TYPE_EDB9312              451
#define MACH_TYPE_OMAP_GENERIC         452
#define MACH_TYPE_EDB9301              462
#define MACH_TYPE_EDB9315              463
#define MACH_TYPE_VR1000               475
#define MACH_TYPE_OMAP_PERSEUS2        491
#define MACH_TYPE_E800                 496
#define MACH_TYPE_E750                 497
#define MACH_TYPE_SCB9328              508
#define MACH_TYPE_OMAP_H3              509
#define MACH_TYPE_OMAP_H4              510
#define MACH_TYPE_OMAP_OSK             515
#define MACH_TYPE_TOSA                 520
#define MACH_TYPE_AVILA                526
#define MACH_TYPE_EDB9302              538
#define MACH_TYPE_HUSKY                543
#define MACH_TYPE_SHEPHERD             545
#define MACH_TYPE_H4700                562
#define MACH_TYPE_RX3715               592
#define MACH_TYPE_NSLU2                597
#define MACH_TYPE_E400                 598
#define MACH_TYPE_IXDPG425             604
#define MACH_TYPE_VERSATILE_AB         606
#define MACH_TYPE_EDB9307              607
#define MACH_TYPE_KB9200               612
#define MACH_TYPE_SX1                  613
#define MACH_TYPE_IXDP465              618
#define MACH_TYPE_IXDP2351             619
#define MACH_TYPE_CM4008               624
#define MACH_TYPE_IQ80332              629
#define MACH_TYPE_GTWX5715             641
#define MACH_TYPE_CSB637               648
#define MACH_TYPE_N30                  656
#define MACH_TYPE_NEC_MP900            659
#define MACH_TYPE_KAFA                 662
#define MACH_TYPE_CM41XX               672
#define MACH_TYPE_TS72XX               673
#define MACH_TYPE_OTOM                 680
#define MACH_TYPE_NEXCODER_2440        681
#define MACH_TYPE_ECO920               702
#define MACH_TYPE_ROADRUNNER           704
#define MACH_TYPE_AT91RM9200EK         705
#define MACH_TYPE_SPITZ                713
#define MACH_TYPE_ADSSPHERE            723
#define MACH_TYPE_COLIBRI              729
#define MACH_TYPE_GATEWAY7001          731
#define MACH_TYPE_PCM027               732
#define MACH_TYPE_ANUBIS               734
#define MACH_TYPE_AKITA                744
#define MACH_TYPE_E330                 753
#define MACH_TYPE_NOKIA770             755
#define MACH_TYPE_CARMEVA              769
#define MACH_TYPE_EDB9315A             772
#define MACH_TYPE_STARGATE2            774
#define MACH_TYPE_INTELMOTE2           775
#define MACH_TYPE_TRIZEPS4             776
#define MACH_TYPE_PNX4008              782
#define MACH_TYPE_CPUAT91              787
#define MACH_TYPE_IQ81340SC            799
#define MACH_TYPE_IQ81340MC            801
#define MACH_TYPE_SE4200               809
#define MACH_TYPE_MICRO9               811
#define MACH_TYPE_MICRO9L              812
#define MACH_TYPE_OMAP_PALMTE          817
#define MACH_TYPE_REALVIEW_EB          827
#define MACH_TYPE_BORZOI               831
#define MACH_TYPE_PALMLD               835
#define MACH_TYPE_IXDP28X5             838
#define MACH_TYPE_OMAP_PALMTT          839
#define MACH_TYPE_ARCOM_ZEUS           841
#define MACH_TYPE_OSIRIS               842
#define MACH_TYPE_PALMTE2              844
#define MACH_TYPE_MX27ADS              846
#define MACH_TYPE_AT91SAM9261EK        848
#define MACH_TYPE_LOFT                 849
#define MACH_TYPE_MX21ADS              851
#define MACH_TYPE_AMS_DELTA            862
#define MACH_TYPE_NAS100D              865
#define MACH_TYPE_MAGICIAN             875
#define MACH_TYPE_CM4002               876
#define MACH_TYPE_NXDKN                880
#define MACH_TYPE_PALMTX               885
#define MACH_TYPE_S3C2413              887
#define MACH_TYPE_WG302V2              890
#define MACH_TYPE_OMAP_2430SDP         900
#define MACH_TYPE_DAVINCI_EVM          901
#define MACH_TYPE_PALMZ72              904
#define MACH_TYPE_NXDB500              905
#define MACH_TYPE_APF9328              906
#define MACH_TYPE_PALMT5               917
#define MACH_TYPE_PALMTC               918
#define MACH_TYPE_OMAP_APOLLON         919
#define MACH_TYPE_ATEB9200             923
#define MACH_TYPE_N35                  927
#define MACH_TYPE_LOGICPD_PXA270       930
#define MACH_TYPE_NXEB500HMI           941
#define MACH_TYPE_ESPRESSO             949
#define MACH_TYPE_RX1950               952
#define MACH_TYPE_GESBC9312            958
#define MACH_TYPE_PICOTUX2XX           963
#define MACH_TYPE_DSMG600              964
#define MACH_TYPE_OMAP_FSAMPLE         970
#define MACH_TYPE_SNAPPER_CL15         986
#define MACH_TYPE_OMAP_PALMZ71         993
#define MACH_TYPE_SMDK2412             1009
#define MACH_TYPE_SMDK2413             1022
#define MACH_TYPE_AML_M5900            1024
#define MACH_TYPE_BALLOON3             1029
#define MACH_TYPE_ECBAT91              1072
#define MACH_TYPE_ONEARM               1075
#define MACH_TYPE_SMDK2443             1084
#define MACH_TYPE_FSG                  1091
#define MACH_TYPE_AT91SAM9260EK        1099
#define MACH_TYPE_GLANTANK             1100
#define MACH_TYPE_N2100                1101
#define MACH_TYPE_IM42XX               1105
#define MACH_TYPE_QT2410               1108
#define MACH_TYPE_KIXRP435             1109
#define MACH_TYPE_CC9P9360DEV          1114
#define MACH_TYPE_EDB9302A             1127
#define MACH_TYPE_EDB9307A             1128
#define MACH_TYPE_OMAP_3430SDP         1138
#define MACH_TYPE_VSTMS                1140
#define MACH_TYPE_MICRO9M              1169
#define MACH_TYPE_BUG                  1179
#define MACH_TYPE_AT91SAM9263EK        1202
#define MACH_TYPE_EM7210               1212
#define MACH_TYPE_VPAC270              1227
#define MACH_TYPE_TREO680              1230
#define MACH_TYPE_ZYLONITE             1233
#define MACH_TYPE_MX31LITE             1236
#define MACH_TYPE_MIOA701              1257
#define MACH_TYPE_ARMADILLO5X0         1260
#define MACH_TYPE_CC9P9360JS           1264
#define MACH_TYPE_SMDK6400             1270
#define MACH_TYPE_NOKIA_N800           1271
#define MACH_TYPE_EP80219              1281
#define MACH_TYPE_GORAMO_MLR           1292
#define MACH_TYPE_EM_X270              1297
#define MACH_TYPE_NEO1973_GTA02        1304
#define MACH_TYPE_AT91SAM9RLEK         1326
#define MACH_TYPE_COLIBRI320           1340
#define MACH_TYPE_CAM60                1351
#define MACH_TYPE_AT91EB01             1354
#define MACH_TYPE_DB88F5281            1358
#define MACH_TYPE_CSB726               1359
#define MACH_TYPE_DAVINCI_DM6467_EVM   1380
#define MACH_TYPE_DAVINCI_DM355_EVM    1381
#define MACH_TYPE_LITTLETON            1388
#define MACH_TYPE_IM4004               1400
#define MACH_TYPE_REALVIEW_PB11MP      1407
#define MACH_TYPE_MX27_3DS             1430
#define MACH_TYPE_HALIBUT              1439
#define MACH_TYPE_TROUT                1440
#define MACH_TYPE_TCT_HAMMER           1460
#define MACH_TYPE_HERALD               1461
#define MACH_TYPE_SIM_ONE              1476
#define MACH_TYPE_JIVE                 1490
#define MACH_TYPE_SAM9_L9260           1501
#define MACH_TYPE_REALVIEW_PB1176      1504
#define MACH_TYPE_YL9200               1507
#define MACH_TYPE_RD88F5182            1508
#define MACH_TYPE_KUROBOX_PRO          1509
#define MACH_TYPE_MX31_3DS             1511
#define MACH_TYPE_QONG                 1524
#define MACH_TYPE_OMAP2EVM             1534
#define MACH_TYPE_OMAP3EVM             1535
#define MACH_TYPE_DNS323               1542
#define MACH_TYPE_OMAP3_BEAGLE         1546
#define MACH_TYPE_NOKIA_N810           1548
#define MACH_TYPE_PCM038               1551
#define MACH_TYPE_SG310                1564
#define MACH_TYPE_TS209                1565
#define MACH_TYPE_AT91CAP9ADK          1566
#define MACH_TYPE_MX31MOBOARD          1574
#define MACH_TYPE_VISION_EP9307        1578
#define MACH_TYPE_TERASTATION_PRO2     1584
#define MACH_TYPE_LINKSTATION_PRO      1585
#define MACH_TYPE_E350                 1596
#define MACH_TYPE_TS409                1601
#define MACH_TYPE_RSI_EWS              1609
#define MACH_TYPE_CM_X300              1616
#define MACH_TYPE_AT91SAM9G20EK        1624
#define MACH_TYPE_SMDK6410             1626
#define MACH_TYPE_U300                 1627
#define MACH_TYPE_WRT350N_V2           1633
#define MACH_TYPE_OMAP_LDP             1639
#define MACH_TYPE_MX35_3DS             1645
#define MACH_TYPE_NEUROS_OSD2          1647
#define MACH_TYPE_TRIZEPS4WL           1649
#define MACH_TYPE_TS78XX               1652
#define MACH_TYPE_SFFSDR               1657
#define MACH_TYPE_PCM037               1673
#define MACH_TYPE_DB88F6281_BP         1680
#define MACH_TYPE_RD88F6192_NAS        1681
#define MACH_TYPE_RD88F6281            1682
#define MACH_TYPE_DB78X00_BP           1683
#define MACH_TYPE_SMDK2416             1685
#define MACH_TYPE_WBD111               1690
#define MACH_TYPE_MV2120               1693
#define MACH_TYPE_MX51_3DS             1696
#define MACH_TYPE_IMX27LITE            1701
#define MACH_TYPE_USB_A9260            1709
#define MACH_TYPE_USB_A9263            1710
#define MACH_TYPE_QIL_A9260            1711
#define MACH_TYPE_KZM_ARM11_01         1722
#define MACH_TYPE_NOKIA_N810_WIMAX     1727
#define MACH_TYPE_SAPPHIRE             1729
#define MACH_TYPE_STMP37XX             1732
#define MACH_TYPE_STMP378X             1733
#define MACH_TYPE_EZX_A780             1740
#define MACH_TYPE_EZX_E680             1741
#define MACH_TYPE_EZX_A1200            1742
#define MACH_TYPE_EZX_E6               1743
#define MACH_TYPE_EZX_E2               1744
#define MACH_TYPE_EZX_A910             1745
#define MACH_TYPE_EDMINI_V2            1756
#define MACH_TYPE_ZIPIT2               1757
#define MACH_TYPE_OMAP3_PANDORA        1761
#define MACH_TYPE_MSS2                 1766
#define MACH_TYPE_LB88RC8480           1769
#define MACH_TYPE_MX25_3DS             1771
#define MACH_TYPE_OMAP3530_LV_SOM      1773
#define MACH_TYPE_DAVINCI_DA830_EVM    1781
#define MACH_TYPE_DOVE_DB              1788
#define MACH_TYPE_OVERO                1798
#define MACH_TYPE_AT2440EVB            1799
#define MACH_TYPE_NEOCORE926           1800
#define MACH_TYPE_WNR854T              1801
#define MACH_TYPE_RD88F5181L_GE        1812
#define MACH_TYPE_RD88F5181L_FXO       1818
#define MACH_TYPE_STAMP9G20            1824
#define MACH_TYPE_SMDKC100             1826
#define MACH_TYPE_TAVOREVB             1827
#define MACH_TYPE_SAAR                 1828
#define MACH_TYPE_AT91SAM9M10G45EK     1830
#define MACH_TYPE_USB_A9G20            1841
#define MACH_TYPE_MXLADS               1851
#define MACH_TYPE_LINKSTATION_MINI     1858
#define MACH_TYPE_AFEB9260             1859
#define MACH_TYPE_IMX27IPCAM           1871
#define MACH_TYPE_BK3                  1880
#define MACH_TYPE_RD88F6183AP_GE       1894
#define MACH_TYPE_REALVIEW_PBA8        1897
#define MACH_TYPE_REALVIEW_PBX         1901
#define MACH_TYPE_MICRO9S              1902
#define MACH_TYPE_RUT100               1908
#define MACH_TYPE_G3EVM                1919
#define MACH_TYPE_W90P910EVB           1921
#define MACH_TYPE_W90P950EVB           1923
#define MACH_TYPE_W90N960EVB           1924
#define MACH_TYPE_MV88F6281GTW_GE      1932
#define MACH_TYPE_NCP                  1933
#define MACH_TYPE_DAVINCI_DM365_EVM    1939
#define MACH_TYPE_CENTRO               1944
#define MACH_TYPE_NOKIA_RX51           1955
#define MACH_TYPE_OMAP_ZOOM2           1967
#define MACH_TYPE_CPUAT9260            1973
#define MACH_TYPE_EUKREA_CPUIMX27      1975
#define MACH_TYPE_ACS5K                1982
#define MACH_TYPE_SNAPPER_9260         1987
#define MACH_TYPE_DSM320               1988
#define MACH_TYPE_EXEDA                1994
#define MACH_TYPE_MINI2440             1999
#define MACH_TYPE_COLIBRI300           2000
#define MACH_TYPE_LINKSTATION_LS_HGL   2005
#define MACH_TYPE_CPUAT9G20            2031
#define MACH_TYPE_SMDK6440             2032
#define MACH_TYPE_NAS4220B             2038
#define MACH_TYPE_ZYLONITE2            2042
#define MACH_TYPE_ASPENITE             2043
#define MACH_TYPE_TTC_DKB              2045
#define MACH_TYPE_PCM043               2072
#define MACH_TYPE_SHEEVAPLUG           2097
#define MACH_TYPE_AVENGERS_LITE        2104
#define MACH_TYPE_MX51_BABBAGE         2125
#define MACH_TYPE_RD78X00_MASA         2135
#define MACH_TYPE_DM355_LEOPARD        2138
#define MACH_TYPE_TS219                2139
#define MACH_TYPE_PCA100               2149
#define MACH_TYPE_DAVINCI_DA850_EVM    2157
#define MACH_TYPE_AT91SAM9G10EK        2159
#define MACH_TYPE_OMAP_4430SDP         2160
#define MACH_TYPE_MAGX_ZN5             2162
#define MACH_TYPE_OMAP3_TORPEDO        2178
#define MACH_TYPE_ANW6410              2183
#define MACH_TYPE_IMX27_VISSTRIM_M10   2187
#define MACH_TYPE_PORTUXG20            2191
#define MACH_TYPE_SMDKC110             2193
#define MACH_TYPE_OMAP3517EVM          2200
#define MACH_TYPE_NETSPACE_V2          2201
#define MACH_TYPE_NETSPACE_MAX_V2      2202
#define MACH_TYPE_D2NET_V2             2203
#define MACH_TYPE_NET2BIG_V2           2204
#define MACH_TYPE_NET5BIG_V2           2206
#define MACH_TYPE_INETSPACE_V2         2208
#define MACH_TYPE_AT91SAM9G45EKES      2212
#define MACH_TYPE_SPEAR600             2236
#define MACH_TYPE_SPEAR300             2237
#define MACH_TYPE_LILLY1131            2239
#define MACH_TYPE_HMT                  2254
#define MACH_TYPE_VEXPRESS             2272
#define MACH_TYPE_D2NET                2282
#define MACH_TYPE_BIGDISK              2283
#define MACH_TYPE_AT91SAM9G20EK_2MMC   2288
#define MACH_TYPE_BCMRING              2289
#define MACH_TYPE_MAHIMAHI             2304
#define MACH_TYPE_SMDK6442             2324
#define MACH_TYPE_OPENRD_BASE          2325
#define MACH_TYPE_DEVKIT8000           2330
#define MACH_TYPE_MX51_EFIKAMX         2336
#define MACH_TYPE_CM_T35               2341
#define MACH_TYPE_NET2BIG              2342
#define MACH_TYPE_IGEP0020             2344
#define MACH_TYPE_NUC932EVB            2356
#define MACH_TYPE_OPENRD_CLIENT        2361
#define MACH_TYPE_U8500                2368
#define MACH_TYPE_MX51_EFIKASB         2370
#define MACH_TYPE_MARVELL_JASPER       2382
#define MACH_TYPE_FLINT                2383
#define MACH_TYPE_TAVOREVB3            2384
#define MACH_TYPE_TOUCHBOOK            2393
#define MACH_TYPE_RAUMFELD_RC          2413
#define MACH_TYPE_RAUMFELD_CONNECTOR   2414
#define MACH_TYPE_RAUMFELD_SPEAKER     2415
#define MACH_TYPE_TNETV107X            2418
#define MACH_TYPE_SMDKV210             2456
#define MACH_TYPE_OMAP_ZOOM3           2464
#define MACH_TYPE_OMAP_3630SDP         2465
#define MACH_TYPE_SMARTQ7              2479
#define MACH_TYPE_G4EVM                2493
#define MACH_TYPE_OMAPL138_HAWKBOARD   2495
#define MACH_TYPE_TS41X                2502
#define MACH_TYPE_PHY3250              2511
#define MACH_TYPE_MINI6410             2520
#define MACH_TYPE_MX28EVK              2531
#define MACH_TYPE_SMARTQ5              2534
#define MACH_TYPE_DAVINCI_DM6467TEVM   2548
#define MACH_TYPE_MXT_TD60             2550
#define MACH_TYPE_CAPC7117             2612
#define MACH_TYPE_ICONTROL             2624
#define MACH_TYPE_GPLUGD               2625
#define MACH_TYPE_QSD8X50A_ST1_5       2627
#define MACH_TYPE_MX23EVK              2629
#define MACH_TYPE_AP4EVB               2630
#define MACH_TYPE_MITYOMAPL138         2650
#define MACH_TYPE_GURUPLUG             2659
#define MACH_TYPE_SPEAR310             2660
#define MACH_TYPE_SPEAR320             2661
#define MACH_TYPE_AQUILA               2676
#define MACH_TYPE_ESATA_SHEEVAPLUG     2678
#define MACH_TYPE_MSM7X30_SURF         2679
#define MACH_TYPE_TERASTATION_WXL      2697
#define MACH_TYPE_MSM7X25_SURF         2703
#define MACH_TYPE_MSM7X25_FFA          2704
#define MACH_TYPE_MSM7X27_SURF         2705
#define MACH_TYPE_MSM7X27_FFA          2706
#define MACH_TYPE_MSM7X30_FFA          2707
#define MACH_TYPE_QSD8X50_SURF         2708
#define MACH_TYPE_MX53_EVK             2716
#define MACH_TYPE_IGEP0030             2717
#define MACH_TYPE_SBC3530              2722
#define MACH_TYPE_SAARB                2727
#define MACH_TYPE_HARMONY              2731
#define MACH_TYPE_MSM7X30_FLUID        2741
#define MACH_TYPE_CM_T3517             2750
#define MACH_TYPE_WBD222               2753
#define MACH_TYPE_MSM8X60_SURF         2755
#define MACH_TYPE_MSM8X60_SIM          2756
#define MACH_TYPE_TCC8000_SDK          2758
#define MACH_TYPE_CNS3420VB            2776
#define MACH_TYPE_OMAP4_PANDA          2791
#define MACH_TYPE_TI8168EVM            2800
#define MACH_TYPE_TETON_BGA            2816
#define MACH_TYPE_EUKREA_CPUIMX25SD    2820
#define MACH_TYPE_EUKREA_CPUIMX35SD    2821
#define MACH_TYPE_EUKREA_CPUIMX51SD    2822
#define MACH_TYPE_EUKREA_CPUIMX51      2823
#define MACH_TYPE_SMDKC210             2838
#define MACH_TYPE_T5325                2846
#define MACH_TYPE_INCOME               2849
#define MACH_TYPE_MESON                2853
#define MACH_TYPE_GONI                 2862
#define MACH_TYPE_BV07                 2882
#define MACH_TYPE_OPENRD_ULTIMATE      2884
#define MACH_TYPE_DEVIXP               2885
#define MACH_TYPE_MICCPT               2886
#define MACH_TYPE_MIC256               2887
#define MACH_TYPE_U5500                2890
#define MACH_TYPE_LINKSTATION_LSCHL    2913
#define MACH_TYPE_SMDKV310             2925
#define MACH_TYPE_WM8505_7IN_NETBOOK   2928
#define MACH_TYPE_CRANEBOARD           2932
#define MACH_TYPE_SMDK6450             2938
#define MACH_TYPE_BROWNSTONE           2957
#define MACH_TYPE_FLEXIBITY            2965
#define MACH_TYPE_MX50_RDP             2988
#define MACH_TYPE_UNIVERSAL_C210       2989
#define MACH_TYPE_REAL6410             2990
#define MACH_TYPE_DOCKSTAR             2998
#define MACH_TYPE_TI8148EVM            3004
#define MACH_TYPE_SEABOARD             3005
#define MACH_TYPE_MX53_ARD             3010
#define MACH_TYPE_MX53_SMD             3011
#define MACH_TYPE_MSM8X60_RUMI3        3016
#define MACH_TYPE_MSM8X60_FFA          3017
#define MACH_TYPE_CM_A510              3020
#define MACH_TYPE_TX28                 3043
#define MACH_TYPE_PCONTROL_G20         3062
#define MACH_TYPE_VPR200               3087
#define MACH_TYPE_TORBRECK             3090
#define MACH_TYPE_PRIMA2_EVB           3103
#define MACH_TYPE_PAZ00                3128
#define MACH_TYPE_ACMENETUSFOXG20      3129
#define MACH_TYPE_AG5EVM               3189
#define MACH_TYPE_WLF_CRAGG_6410       3207
#define MACH_TYPE_TRIMSLICE            3209
#define MACH_TYPE_MACKEREL             3211
#define MACH_TYPE_KAEN                 3217
#define MACH_TYPE_NOKIA_RM680          3220
#define MACH_TYPE_MSM8960_SIM          3230
#define MACH_TYPE_MSM8960_RUMI3        3231
#define MACH_TYPE_GSIA18S              3234
#define MACH_TYPE_MX53_LOCO            3273
#define MACH_TYPE_WARIO                3288
#define MACH_TYPE_CM_T3730             3290
#define MACH_TYPE_HREFV60              3293
#define MACH_TYPE_ARMLEX4210           3361
#define MACH_TYPE_SNOWBALL             3363
#define MACH_TYPE_XILINX_EP107         3378
#define MACH_TYPE_NURI                 3379
#define MACH_TYPE_ORIGEN               3455
#define MACH_TYPE_XARINA               3476
#define MACH_TYPE_NSPIRE               3503
#define MACH_TYPE_NOKIA_RM696          3522
#define MACH_TYPE_M28EVK               3613
#define MACH_TYPE_KOTA2                3616
#define MACH_TYPE_BONITO               3623
#define MACH_TYPE_SMDK4212             3638
#define MACH_TYPE_APX4DEVKIT           3712
#define MACH_TYPE_SMDK4412             3765
#define MACH_TYPE_MARZEN               3790
#define MACH_TYPE_EMPC_A500            3848
#define MACH_TYPE_U8520                3990
#define MACH_TYPE_URT                  4347
#define MACH_TYPE_KEYSTONE             4390
#define MACH_TYPE_CKB_RZA1H            4780
#define MACH_TYPE_BCM2835              4828
#define MACH_TYPE_CM_3G                4943
#define MACH_TYPE_EMPC_AIMX6           4958
#define MACH_TYPE_DIYEFIS6410          5063
#define MACH_TYPE_MX53_TURING          5064
#define MACH_TYPE_MX6DL_TURING         5066
#define MACH_TYPE_MX53_INDASH          5067
#define MACH_TYPE_MX6Q_INDASH          5068
#define MACH_TYPE_MX6DL_INDASH         5069
#define MACH_TYPE_RTS_G6               5070
#define MACH_TYPE_KA_TITAN             5071
#define MACH_TYPE_CL_SOM_IMX7          5072
#define MACH_TYPE_VVDN_MGSI_VSIS       5073
#define MACH_TYPE_MX6Q_NANO            5074
#define MACH_TYPE_PDU001               5075
#define MACH_TYPE_CAB_PROYK            5076
#define MACH_TYPE_KLIN                 5077
#define MACH_TYPE_ENMAN_STEUERBOX      5078
#define MACH_TYPE_LS_STINGRAY          5079
#define MACH_TYPE_IPDU                 5080
#define MACH_TYPE_LINDA                5081
#define MACH_TYPE_MX6Q_OPENREX         5082
#define MACH_TYPE_ON100                5083
#define MACH_TYPE_EMINDS_RTU12         5084
#define MACH_TYPE_EMINDS_AVL10         5085
#define MACH_TYPE_MAIN_PLC_LME         5086
#define MACH_TYPE_MSPX                 5087
#define MACH_TYPE_CGW_300              5088
#define MACH_TYPE_MX7D_CICADA          5089
#define MACH_TYPE_VIRT2REAL_DM365      5090
#define MACH_TYPE_DM365_VIRT2REAL      5091
#define MACH_TYPE_H6073                5092
#define MACH_TYPE_GTGATEWAY            5093
#define MACH_TYPE_XARINA_STANDARD      5094
#define MACH_TYPE_NOVASOMS             5095
#define MACH_TYPE_NOVASOMP             5096
#define MACH_TYPE_NOVASOMU             5097
#define MACH_TYPE_MX6Q_MPBD            5098
#define MACH_TYPE_NCR_1930             5099
#define MACH_TYPE_UAP301               5100
#define MACH_TYPE_URT02                5101
#define MACH_TYPE_ATC8                 5102
#define MACH_TYPE_IOT_GATEWAY          5103
#define MACH_TYPE_HSM_PHOENIX          5104
#define MACH_TYPE_MISSOURI             5105
#define MACH_TYPE_REMARKABLE           5106
#define MACH_TYPE_FA0113               5107
#define MACH_TYPE_INNOVA_STATNETTAWM   5108

#ifdef CONFIG_ARCH_EBSA110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EBSA110
# endif
# define machine_is_ebsa110()	(machine_arch_type == MACH_TYPE_EBSA110)
#else
# define machine_is_ebsa110()	(0)
#endif

#ifdef CONFIG_ARCH_RPC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RISCPC
# endif
# define machine_is_riscpc()	(machine_arch_type == MACH_TYPE_RISCPC)
#else
# define machine_is_riscpc()	(0)
#endif

#ifdef CONFIG_ARCH_EBSA285
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EBSA285
# endif
# define machine_is_ebsa285()	(machine_arch_type == MACH_TYPE_EBSA285)
#else
# define machine_is_ebsa285()	(0)
#endif

#ifdef CONFIG_ARCH_NETWINDER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETWINDER
# endif
# define machine_is_netwinder()	(machine_arch_type == MACH_TYPE_NETWINDER)
#else
# define machine_is_netwinder()	(0)
#endif

#ifdef CONFIG_ARCH_CATS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CATS
# endif
# define machine_is_cats()	(machine_arch_type == MACH_TYPE_CATS)
#else
# define machine_is_cats()	(0)
#endif

#ifdef CONFIG_ARCH_SHARK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHARK
# endif
# define machine_is_shark()	(machine_arch_type == MACH_TYPE_SHARK)
#else
# define machine_is_shark()	(0)
#endif

#ifdef CONFIG_SA1100_BRUTUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BRUTUS
# endif
# define machine_is_brutus()	(machine_arch_type == MACH_TYPE_BRUTUS)
#else
# define machine_is_brutus()	(0)
#endif

#ifdef CONFIG_ARCH_PERSONAL_SERVER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PERSONAL_SERVER
# endif
# define machine_is_personal_server()	(machine_arch_type == MACH_TYPE_PERSONAL_SERVER)
#else
# define machine_is_personal_server()	(0)
#endif

#ifdef CONFIG_ARCH_L7200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_L7200
# endif
# define machine_is_l7200()	(machine_arch_type == MACH_TYPE_L7200)
#else
# define machine_is_l7200()	(0)
#endif

#ifdef CONFIG_SA1100_PLEB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PLEB
# endif
# define machine_is_pleb()	(machine_arch_type == MACH_TYPE_PLEB)
#else
# define machine_is_pleb()	(0)
#endif

#ifdef CONFIG_ARCH_INTEGRATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INTEGRATOR
# endif
# define machine_is_integrator()	(machine_arch_type == MACH_TYPE_INTEGRATOR)
#else
# define machine_is_integrator()	(0)
#endif

#ifdef CONFIG_SA1100_H3600
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H3600
# endif
# define machine_is_h3600()	(machine_arch_type == MACH_TYPE_H3600)
#else
# define machine_is_h3600()	(0)
#endif

#ifdef CONFIG_ARCH_P720T
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_P720T
# endif
# define machine_is_p720t()	(machine_arch_type == MACH_TYPE_P720T)
#else
# define machine_is_p720t()	(0)
#endif

#ifdef CONFIG_SA1100_ASSABET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ASSABET
# endif
# define machine_is_assabet()	(machine_arch_type == MACH_TYPE_ASSABET)
#else
# define machine_is_assabet()	(0)
#endif

#ifdef CONFIG_SA1100_LART
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LART
# endif
# define machine_is_lart()	(machine_arch_type == MACH_TYPE_LART)
#else
# define machine_is_lart()	(0)
#endif

#ifdef CONFIG_SA1100_GRAPHICSCLIENT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GRAPHICSCLIENT
# endif
# define machine_is_graphicsclient()	(machine_arch_type == MACH_TYPE_GRAPHICSCLIENT)
#else
# define machine_is_graphicsclient()	(0)
#endif

#ifdef CONFIG_SA1100_XP860
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XP860
# endif
# define machine_is_xp860()	(machine_arch_type == MACH_TYPE_XP860)
#else
# define machine_is_xp860()	(0)
#endif

#ifdef CONFIG_SA1100_CERF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CERF
# endif
# define machine_is_cerf()	(machine_arch_type == MACH_TYPE_CERF)
#else
# define machine_is_cerf()	(0)
#endif

#ifdef CONFIG_SA1100_NANOENGINE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NANOENGINE
# endif
# define machine_is_nanoengine()	(machine_arch_type == MACH_TYPE_NANOENGINE)
#else
# define machine_is_nanoengine()	(0)
#endif

#ifdef CONFIG_SA1100_JORNADA720
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JORNADA720
# endif
# define machine_is_jornada720()	(machine_arch_type == MACH_TYPE_JORNADA720)
#else
# define machine_is_jornada720()	(0)
#endif

#ifdef CONFIG_ARCH_EDB7211
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB7211
# endif
# define machine_is_edb7211()	(machine_arch_type == MACH_TYPE_EDB7211)
#else
# define machine_is_edb7211()	(0)
#endif

#ifdef CONFIG_SA1100_PFS168
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PFS168
# endif
# define machine_is_pfs168()	(machine_arch_type == MACH_TYPE_PFS168)
#else
# define machine_is_pfs168()	(0)
#endif

#ifdef CONFIG_SA1100_FLEXANET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FLEXANET
# endif
# define machine_is_flexanet()	(machine_arch_type == MACH_TYPE_FLEXANET)
#else
# define machine_is_flexanet()	(0)
#endif

#ifdef CONFIG_SA1100_SIMPAD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIMPAD
# endif
# define machine_is_simpad()	(machine_arch_type == MACH_TYPE_SIMPAD)
#else
# define machine_is_simpad()	(0)
#endif

#ifdef CONFIG_ARCH_LUBBOCK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LUBBOCK
# endif
# define machine_is_lubbock()	(machine_arch_type == MACH_TYPE_LUBBOCK)
#else
# define machine_is_lubbock()	(0)
#endif

#ifdef CONFIG_ARCH_CLEP7212
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CLEP7212
# endif
# define machine_is_clep7212()	(machine_arch_type == MACH_TYPE_CLEP7212)
#else
# define machine_is_clep7212()	(0)
#endif

#ifdef CONFIG_SA1100_SHANNON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHANNON
# endif
# define machine_is_shannon()	(machine_arch_type == MACH_TYPE_SHANNON)
#else
# define machine_is_shannon()	(0)
#endif

#ifdef CONFIG_SA1100_CONSUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CONSUS
# endif
# define machine_is_consus()	(machine_arch_type == MACH_TYPE_CONSUS)
#else
# define machine_is_consus()	(0)
#endif

#ifdef CONFIG_ARCH_AAED2000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AAED2000
# endif
# define machine_is_aaed2000()	(machine_arch_type == MACH_TYPE_AAED2000)
#else
# define machine_is_aaed2000()	(0)
#endif

#ifdef CONFIG_ARCH_CDB89712
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CDB89712
# endif
# define machine_is_cdb89712()	(machine_arch_type == MACH_TYPE_CDB89712)
#else
# define machine_is_cdb89712()	(0)
#endif

#ifdef CONFIG_SA1100_GRAPHICSMASTER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GRAPHICSMASTER
# endif
# define machine_is_graphicsmaster()	(machine_arch_type == MACH_TYPE_GRAPHICSMASTER)
#else
# define machine_is_graphicsmaster()	(0)
#endif

#ifdef CONFIG_SA1100_ADSBITSY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSBITSY
# endif
# define machine_is_adsbitsy()	(machine_arch_type == MACH_TYPE_ADSBITSY)
#else
# define machine_is_adsbitsy()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_IDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_IDP
# endif
# define machine_is_pxa_idp()	(machine_arch_type == MACH_TYPE_PXA_IDP)
#else
# define machine_is_pxa_idp()	(0)
#endif

#ifdef CONFIG_SA1100_PT_SYSTEM3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PT_SYSTEM3
# endif
# define machine_is_pt_system3()	(machine_arch_type == MACH_TYPE_PT_SYSTEM3)
#else
# define machine_is_pt_system3()	(0)
#endif

#ifdef CONFIG_ARCH_AUTCPU12
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AUTCPU12
# endif
# define machine_is_autcpu12()	(machine_arch_type == MACH_TYPE_AUTCPU12)
#else
# define machine_is_autcpu12()	(0)
#endif

#ifdef CONFIG_SA1100_H3100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H3100
# endif
# define machine_is_h3100()	(machine_arch_type == MACH_TYPE_H3100)
#else
# define machine_is_h3100()	(0)
#endif

#ifdef CONFIG_SA1100_COLLIE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COLLIE
# endif
# define machine_is_collie()	(machine_arch_type == MACH_TYPE_COLLIE)
#else
# define machine_is_collie()	(0)
#endif

#ifdef CONFIG_SA1100_BADGE4
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BADGE4
# endif
# define machine_is_badge4()	(machine_arch_type == MACH_TYPE_BADGE4)
#else
# define machine_is_badge4()	(0)
#endif

#ifdef CONFIG_ARCH_FORTUNET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FORTUNET
# endif
# define machine_is_fortunet()	(machine_arch_type == MACH_TYPE_FORTUNET)
#else
# define machine_is_fortunet()	(0)
#endif

#ifdef CONFIG_ARCH_MX1ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX1ADS
# endif
# define machine_is_mx1ads()	(machine_arch_type == MACH_TYPE_MX1ADS)
#else
# define machine_is_mx1ads()	(0)
#endif

#ifdef CONFIG_ARCH_H7201
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H7201
# endif
# define machine_is_h7201()	(machine_arch_type == MACH_TYPE_H7201)
#else
# define machine_is_h7201()	(0)
#endif

#ifdef CONFIG_ARCH_H7202
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H7202
# endif
# define machine_is_h7202()	(machine_arch_type == MACH_TYPE_H7202)
#else
# define machine_is_h7202()	(0)
#endif

#ifdef CONFIG_ARCH_IQ80321
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80321
# endif
# define machine_is_iq80321()	(machine_arch_type == MACH_TYPE_IQ80321)
#else
# define machine_is_iq80321()	(0)
#endif

#ifdef CONFIG_ARCH_KS8695
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KS8695
# endif
# define machine_is_ks8695()	(machine_arch_type == MACH_TYPE_KS8695)
#else
# define machine_is_ks8695()	(0)
#endif

#ifdef CONFIG_ARCH_SMDK2410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2410
# endif
# define machine_is_smdk2410()	(machine_arch_type == MACH_TYPE_SMDK2410)
#else
# define machine_is_smdk2410()	(0)
#endif

#ifdef CONFIG_ARCH_CEIVA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CEIVA
# endif
# define machine_is_ceiva()	(machine_arch_type == MACH_TYPE_CEIVA)
#else
# define machine_is_ceiva()	(0)
#endif

#ifdef CONFIG_MACH_VOICEBLUE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VOICEBLUE
# endif
# define machine_is_voiceblue()	(machine_arch_type == MACH_TYPE_VOICEBLUE)
#else
# define machine_is_voiceblue()	(0)
#endif

#ifdef CONFIG_ARCH_H5400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H5400
# endif
# define machine_is_h5400()	(machine_arch_type == MACH_TYPE_H5400)
#else
# define machine_is_h5400()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_INNOVATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_INNOVATOR
# endif
# define machine_is_omap_innovator()	(machine_arch_type == MACH_TYPE_OMAP_INNOVATOR)
#else
# define machine_is_omap_innovator()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP2400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2400
# endif
# define machine_is_ixdp2400()	(machine_arch_type == MACH_TYPE_IXDP2400)
#else
# define machine_is_ixdp2400()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP2800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2800
# endif
# define machine_is_ixdp2800()	(machine_arch_type == MACH_TYPE_IXDP2800)
#else
# define machine_is_ixdp2800()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP425
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP425
# endif
# define machine_is_ixdp425()	(machine_arch_type == MACH_TYPE_IXDP425)
#else
# define machine_is_ixdp425()	(0)
#endif

#ifdef CONFIG_SA1100_HACKKIT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HACKKIT
# endif
# define machine_is_hackkit()	(machine_arch_type == MACH_TYPE_HACKKIT)
#else
# define machine_is_hackkit()	(0)
#endif

#ifdef CONFIG_ARCH_IXCDP1100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXCDP1100
# endif
# define machine_is_ixcdp1100()	(machine_arch_type == MACH_TYPE_IXCDP1100)
#else
# define machine_is_ixcdp1100()	(0)
#endif

#ifdef CONFIG_ARCH_AT91RM9200DK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91RM9200DK
# endif
# define machine_is_at91rm9200dk()	(machine_arch_type == MACH_TYPE_AT91RM9200DK)
#else
# define machine_is_at91rm9200dk()	(0)
#endif

#ifdef CONFIG_ARCH_CINTEGRATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CINTEGRATOR
# endif
# define machine_is_cintegrator()	(machine_arch_type == MACH_TYPE_CINTEGRATOR)
#else
# define machine_is_cintegrator()	(0)
#endif

#ifdef CONFIG_ARCH_VIPER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VIPER
# endif
# define machine_is_viper()	(machine_arch_type == MACH_TYPE_VIPER)
#else
# define machine_is_viper()	(0)
#endif

#ifdef CONFIG_ARCH_ADI_COYOTE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADI_COYOTE
# endif
# define machine_is_adi_coyote()	(machine_arch_type == MACH_TYPE_ADI_COYOTE)
#else
# define machine_is_adi_coyote()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP2401
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2401
# endif
# define machine_is_ixdp2401()	(machine_arch_type == MACH_TYPE_IXDP2401)
#else
# define machine_is_ixdp2401()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP2801
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2801
# endif
# define machine_is_ixdp2801()	(machine_arch_type == MACH_TYPE_IXDP2801)
#else
# define machine_is_ixdp2801()	(0)
#endif

#ifdef CONFIG_ARCH_IQ31244
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ31244
# endif
# define machine_is_iq31244()	(machine_arch_type == MACH_TYPE_IQ31244)
#else
# define machine_is_iq31244()	(0)
#endif

#ifdef CONFIG_ARCH_BAST
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BAST
# endif
# define machine_is_bast()	(machine_arch_type == MACH_TYPE_BAST)
#else
# define machine_is_bast()	(0)
#endif

#ifdef CONFIG_ARCH_H1940
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H1940
# endif
# define machine_is_h1940()	(machine_arch_type == MACH_TYPE_H1940)
#else
# define machine_is_h1940()	(0)
#endif

#ifdef CONFIG_ARCH_ENP2611
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ENP2611
# endif
# define machine_is_enp2611()	(machine_arch_type == MACH_TYPE_ENP2611)
#else
# define machine_is_enp2611()	(0)
#endif

#ifdef CONFIG_ARCH_S3C2440
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C2440
# endif
# define machine_is_s3c2440()	(machine_arch_type == MACH_TYPE_S3C2440)
#else
# define machine_is_s3c2440()	(0)
#endif

#ifdef CONFIG_ARCH_GUMSTIX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GUMSTIX
# endif
# define machine_is_gumstix()	(machine_arch_type == MACH_TYPE_GUMSTIX)
#else
# define machine_is_gumstix()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_H2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_H2
# endif
# define machine_is_omap_h2()	(machine_arch_type == MACH_TYPE_OMAP_H2)
#else
# define machine_is_omap_h2()	(0)
#endif

#ifdef CONFIG_MACH_E740
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E740
# endif
# define machine_is_e740()	(machine_arch_type == MACH_TYPE_E740)
#else
# define machine_is_e740()	(0)
#endif

#ifdef CONFIG_ARCH_IQ80331
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80331
# endif
# define machine_is_iq80331()	(machine_arch_type == MACH_TYPE_IQ80331)
#else
# define machine_is_iq80331()	(0)
#endif

#ifdef CONFIG_ARCH_VERSATILE_PB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VERSATILE_PB
# endif
# define machine_is_versatile_pb()	(machine_arch_type == MACH_TYPE_VERSATILE_PB)
#else
# define machine_is_versatile_pb()	(0)
#endif

#ifdef CONFIG_MACH_KEV7A400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KEV7A400
# endif
# define machine_is_kev7a400()	(machine_arch_type == MACH_TYPE_KEV7A400)
#else
# define machine_is_kev7a400()	(0)
#endif

#ifdef CONFIG_MACH_LPD7A400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LPD7A400
# endif
# define machine_is_lpd7a400()	(machine_arch_type == MACH_TYPE_LPD7A400)
#else
# define machine_is_lpd7a400()	(0)
#endif

#ifdef CONFIG_MACH_LPD7A404
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LPD7A404
# endif
# define machine_is_lpd7a404()	(machine_arch_type == MACH_TYPE_LPD7A404)
#else
# define machine_is_lpd7a404()	(0)
#endif

#ifdef CONFIG_MACH_CSB337
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSB337
# endif
# define machine_is_csb337()	(machine_arch_type == MACH_TYPE_CSB337)
#else
# define machine_is_csb337()	(0)
#endif

#ifdef CONFIG_MACH_MAINSTONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MAINSTONE
# endif
# define machine_is_mainstone()	(machine_arch_type == MACH_TYPE_MAINSTONE)
#else
# define machine_is_mainstone()	(0)
#endif

#ifdef CONFIG_MACH_LITE300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LITE300
# endif
# define machine_is_lite300()	(machine_arch_type == MACH_TYPE_LITE300)
#else
# define machine_is_lite300()	(0)
#endif

#ifdef CONFIG_MACH_XCEP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XCEP
# endif
# define machine_is_xcep()	(machine_arch_type == MACH_TYPE_XCEP)
#else
# define machine_is_xcep()	(0)
#endif

#ifdef CONFIG_MACH_ARCOM_VULCAN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARCOM_VULCAN
# endif
# define machine_is_arcom_vulcan()	(machine_arch_type == MACH_TYPE_ARCOM_VULCAN)
#else
# define machine_is_arcom_vulcan()	(0)
#endif

#ifdef CONFIG_MACH_NOMADIK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOMADIK
# endif
# define machine_is_nomadik()	(machine_arch_type == MACH_TYPE_NOMADIK)
#else
# define machine_is_nomadik()	(0)
#endif

#ifdef CONFIG_MACH_CORGI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CORGI
# endif
# define machine_is_corgi()	(machine_arch_type == MACH_TYPE_CORGI)
#else
# define machine_is_corgi()	(0)
#endif

#ifdef CONFIG_MACH_POODLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_POODLE
# endif
# define machine_is_poodle()	(machine_arch_type == MACH_TYPE_POODLE)
#else
# define machine_is_poodle()	(0)
#endif

#ifdef CONFIG_MACH_ARMCORE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMCORE
# endif
# define machine_is_armcore()	(machine_arch_type == MACH_TYPE_ARMCORE)
#else
# define machine_is_armcore()	(0)
#endif

#ifdef CONFIG_MACH_MX31ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX31ADS
# endif
# define machine_is_mx31ads()	(machine_arch_type == MACH_TYPE_MX31ADS)
#else
# define machine_is_mx31ads()	(0)
#endif

#ifdef CONFIG_MACH_HIMALAYA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HIMALAYA
# endif
# define machine_is_himalaya()	(machine_arch_type == MACH_TYPE_HIMALAYA)
#else
# define machine_is_himalaya()	(0)
#endif

#ifdef CONFIG_MACH_EDB9312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9312
# endif
# define machine_is_edb9312()	(machine_arch_type == MACH_TYPE_EDB9312)
#else
# define machine_is_edb9312()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_GENERIC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_GENERIC
# endif
# define machine_is_omap_generic()	(machine_arch_type == MACH_TYPE_OMAP_GENERIC)
#else
# define machine_is_omap_generic()	(0)
#endif

#ifdef CONFIG_MACH_EDB9301
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9301
# endif
# define machine_is_edb9301()	(machine_arch_type == MACH_TYPE_EDB9301)
#else
# define machine_is_edb9301()	(0)
#endif

#ifdef CONFIG_MACH_EDB9315
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9315
# endif
# define machine_is_edb9315()	(machine_arch_type == MACH_TYPE_EDB9315)
#else
# define machine_is_edb9315()	(0)
#endif

#ifdef CONFIG_MACH_VR1000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VR1000
# endif
# define machine_is_vr1000()	(machine_arch_type == MACH_TYPE_VR1000)
#else
# define machine_is_vr1000()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_PERSEUS2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_PERSEUS2
# endif
# define machine_is_omap_perseus2()	(machine_arch_type == MACH_TYPE_OMAP_PERSEUS2)
#else
# define machine_is_omap_perseus2()	(0)
#endif

#ifdef CONFIG_MACH_E800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E800
# endif
# define machine_is_e800()	(machine_arch_type == MACH_TYPE_E800)
#else
# define machine_is_e800()	(0)
#endif

#ifdef CONFIG_MACH_E750
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E750
# endif
# define machine_is_e750()	(machine_arch_type == MACH_TYPE_E750)
#else
# define machine_is_e750()	(0)
#endif

#ifdef CONFIG_MACH_SCB9328
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SCB9328
# endif
# define machine_is_scb9328()	(machine_arch_type == MACH_TYPE_SCB9328)
#else
# define machine_is_scb9328()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_H3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_H3
# endif
# define machine_is_omap_h3()	(machine_arch_type == MACH_TYPE_OMAP_H3)
#else
# define machine_is_omap_h3()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_H4
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_H4
# endif
# define machine_is_omap_h4()	(machine_arch_type == MACH_TYPE_OMAP_H4)
#else
# define machine_is_omap_h4()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_OSK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_OSK
# endif
# define machine_is_omap_osk()	(machine_arch_type == MACH_TYPE_OMAP_OSK)
#else
# define machine_is_omap_osk()	(0)
#endif

#ifdef CONFIG_MACH_TOSA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TOSA
# endif
# define machine_is_tosa()	(machine_arch_type == MACH_TYPE_TOSA)
#else
# define machine_is_tosa()	(0)
#endif

#ifdef CONFIG_MACH_AVILA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AVILA
# endif
# define machine_is_avila()	(machine_arch_type == MACH_TYPE_AVILA)
#else
# define machine_is_avila()	(0)
#endif

#ifdef CONFIG_MACH_EDB9302
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9302
# endif
# define machine_is_edb9302()	(machine_arch_type == MACH_TYPE_EDB9302)
#else
# define machine_is_edb9302()	(0)
#endif

#ifdef CONFIG_MACH_HUSKY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HUSKY
# endif
# define machine_is_husky()	(machine_arch_type == MACH_TYPE_HUSKY)
#else
# define machine_is_husky()	(0)
#endif

#ifdef CONFIG_MACH_SHEPHERD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHEPHERD
# endif
# define machine_is_shepherd()	(machine_arch_type == MACH_TYPE_SHEPHERD)
#else
# define machine_is_shepherd()	(0)
#endif

#ifdef CONFIG_MACH_H4700
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H4700
# endif
# define machine_is_h4700()	(machine_arch_type == MACH_TYPE_H4700)
#else
# define machine_is_h4700()	(0)
#endif

#ifdef CONFIG_MACH_RX3715
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RX3715
# endif
# define machine_is_rx3715()	(machine_arch_type == MACH_TYPE_RX3715)
#else
# define machine_is_rx3715()	(0)
#endif

#ifdef CONFIG_MACH_NSLU2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NSLU2
# endif
# define machine_is_nslu2()	(machine_arch_type == MACH_TYPE_NSLU2)
#else
# define machine_is_nslu2()	(0)
#endif

#ifdef CONFIG_MACH_E400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E400
# endif
# define machine_is_e400()	(machine_arch_type == MACH_TYPE_E400)
#else
# define machine_is_e400()	(0)
#endif

#ifdef CONFIG_MACH_IXDPG425
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDPG425
# endif
# define machine_is_ixdpg425()	(machine_arch_type == MACH_TYPE_IXDPG425)
#else
# define machine_is_ixdpg425()	(0)
#endif

#ifdef CONFIG_MACH_VERSATILE_AB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VERSATILE_AB
# endif
# define machine_is_versatile_ab()	(machine_arch_type == MACH_TYPE_VERSATILE_AB)
#else
# define machine_is_versatile_ab()	(0)
#endif

#ifdef CONFIG_MACH_EDB9307
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9307
# endif
# define machine_is_edb9307()	(machine_arch_type == MACH_TYPE_EDB9307)
#else
# define machine_is_edb9307()	(0)
#endif

#ifdef CONFIG_MACH_KB9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KB9200
# endif
# define machine_is_kb9200()	(machine_arch_type == MACH_TYPE_KB9200)
#else
# define machine_is_kb9200()	(0)
#endif

#ifdef CONFIG_MACH_SX1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SX1
# endif
# define machine_is_sx1()	(machine_arch_type == MACH_TYPE_SX1)
#else
# define machine_is_sx1()	(0)
#endif

#ifdef CONFIG_MACH_IXDP465
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP465
# endif
# define machine_is_ixdp465()	(machine_arch_type == MACH_TYPE_IXDP465)
#else
# define machine_is_ixdp465()	(0)
#endif

#ifdef CONFIG_MACH_IXDP2351
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2351
# endif
# define machine_is_ixdp2351()	(machine_arch_type == MACH_TYPE_IXDP2351)
#else
# define machine_is_ixdp2351()	(0)
#endif

#ifdef CONFIG_MACH_CM4008
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM4008
# endif
# define machine_is_cm4008()	(machine_arch_type == MACH_TYPE_CM4008)
#else
# define machine_is_cm4008()	(0)
#endif

#ifdef CONFIG_MACH_IQ80332
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80332
# endif
# define machine_is_iq80332()	(machine_arch_type == MACH_TYPE_IQ80332)
#else
# define machine_is_iq80332()	(0)
#endif

#ifdef CONFIG_MACH_GTWX5715
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GTWX5715
# endif
# define machine_is_gtwx5715()	(machine_arch_type == MACH_TYPE_GTWX5715)
#else
# define machine_is_gtwx5715()	(0)
#endif

#ifdef CONFIG_MACH_CSB637
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSB637
# endif
# define machine_is_csb637()	(machine_arch_type == MACH_TYPE_CSB637)
#else
# define machine_is_csb637()	(0)
#endif

#ifdef CONFIG_MACH_N30
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_N30
# endif
# define machine_is_n30()	(machine_arch_type == MACH_TYPE_N30)
#else
# define machine_is_n30()	(0)
#endif

#ifdef CONFIG_MACH_NEC_MP900
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEC_MP900
# endif
# define machine_is_nec_mp900()	(machine_arch_type == MACH_TYPE_NEC_MP900)
#else
# define machine_is_nec_mp900()	(0)
#endif

#ifdef CONFIG_MACH_KAFA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KAFA
# endif
# define machine_is_kafa()	(machine_arch_type == MACH_TYPE_KAFA)
#else
# define machine_is_kafa()	(0)
#endif

#ifdef CONFIG_MACH_CM41XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM41XX
# endif
# define machine_is_cm41xx()	(machine_arch_type == MACH_TYPE_CM41XX)
#else
# define machine_is_cm41xx()	(0)
#endif

#ifdef CONFIG_MACH_TS72XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TS72XX
# endif
# define machine_is_ts72xx()	(machine_arch_type == MACH_TYPE_TS72XX)
#else
# define machine_is_ts72xx()	(0)
#endif

#ifdef CONFIG_MACH_OTOM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OTOM
# endif
# define machine_is_otom()	(machine_arch_type == MACH_TYPE_OTOM)
#else
# define machine_is_otom()	(0)
#endif

#ifdef CONFIG_MACH_NEXCODER_2440
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEXCODER_2440
# endif
# define machine_is_nexcoder_2440()	(machine_arch_type == MACH_TYPE_NEXCODER_2440)
#else
# define machine_is_nexcoder_2440()	(0)
#endif

#ifdef CONFIG_MACH_ECO920
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ECO920
# endif
# define machine_is_eco920()	(machine_arch_type == MACH_TYPE_ECO920)
#else
# define machine_is_eco920()	(0)
#endif

#ifdef CONFIG_MACH_ROADRUNNER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ROADRUNNER
# endif
# define machine_is_roadrunner()	(machine_arch_type == MACH_TYPE_ROADRUNNER)
#else
# define machine_is_roadrunner()	(0)
#endif

#ifdef CONFIG_MACH_AT91RM9200EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91RM9200EK
# endif
# define machine_is_at91rm9200ek()	(machine_arch_type == MACH_TYPE_AT91RM9200EK)
#else
# define machine_is_at91rm9200ek()	(0)
#endif

#ifdef CONFIG_MACH_SPITZ
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPITZ
# endif
# define machine_is_spitz()	(machine_arch_type == MACH_TYPE_SPITZ)
#else
# define machine_is_spitz()	(0)
#endif

#ifdef CONFIG_MACH_ADSSPHERE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSSPHERE
# endif
# define machine_is_adssphere()	(machine_arch_type == MACH_TYPE_ADSSPHERE)
#else
# define machine_is_adssphere()	(0)
#endif

#ifdef CONFIG_MACH_COLIBRI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COLIBRI
# endif
# define machine_is_colibri()	(machine_arch_type == MACH_TYPE_COLIBRI)
#else
# define machine_is_colibri()	(0)
#endif

#ifdef CONFIG_MACH_GATEWAY7001
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GATEWAY7001
# endif
# define machine_is_gateway7001()	(machine_arch_type == MACH_TYPE_GATEWAY7001)
#else
# define machine_is_gateway7001()	(0)
#endif

#ifdef CONFIG_MACH_PCM027
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCM027
# endif
# define machine_is_pcm027()	(machine_arch_type == MACH_TYPE_PCM027)
#else
# define machine_is_pcm027()	(0)
#endif

#ifdef CONFIG_MACH_ANUBIS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ANUBIS
# endif
# define machine_is_anubis()	(machine_arch_type == MACH_TYPE_ANUBIS)
#else
# define machine_is_anubis()	(0)
#endif

#ifdef CONFIG_MACH_AKITA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AKITA
# endif
# define machine_is_akita()	(machine_arch_type == MACH_TYPE_AKITA)
#else
# define machine_is_akita()	(0)
#endif

#ifdef CONFIG_MACH_E330
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E330
# endif
# define machine_is_e330()	(machine_arch_type == MACH_TYPE_E330)
#else
# define machine_is_e330()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA770
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA770
# endif
# define machine_is_nokia770()	(machine_arch_type == MACH_TYPE_NOKIA770)
#else
# define machine_is_nokia770()	(0)
#endif

#ifdef CONFIG_MACH_CARMEVA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CARMEVA
# endif
# define machine_is_carmeva()	(machine_arch_type == MACH_TYPE_CARMEVA)
#else
# define machine_is_carmeva()	(0)
#endif

#ifdef CONFIG_MACH_EDB9315A
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9315A
# endif
# define machine_is_edb9315a()	(machine_arch_type == MACH_TYPE_EDB9315A)
#else
# define machine_is_edb9315a()	(0)
#endif

#ifdef CONFIG_MACH_STARGATE2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STARGATE2
# endif
# define machine_is_stargate2()	(machine_arch_type == MACH_TYPE_STARGATE2)
#else
# define machine_is_stargate2()	(0)
#endif

#ifdef CONFIG_MACH_INTELMOTE2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INTELMOTE2
# endif
# define machine_is_intelmote2()	(machine_arch_type == MACH_TYPE_INTELMOTE2)
#else
# define machine_is_intelmote2()	(0)
#endif

#ifdef CONFIG_MACH_TRIZEPS4
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TRIZEPS4
# endif
# define machine_is_trizeps4()	(machine_arch_type == MACH_TYPE_TRIZEPS4)
#else
# define machine_is_trizeps4()	(0)
#endif

#ifdef CONFIG_MACH_PNX4008
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PNX4008
# endif
# define machine_is_pnx4008()	(machine_arch_type == MACH_TYPE_PNX4008)
#else
# define machine_is_pnx4008()	(0)
#endif

#ifdef CONFIG_MACH_CPUAT91
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CPUAT91
# endif
# define machine_is_cpuat91()	(machine_arch_type == MACH_TYPE_CPUAT91)
#else
# define machine_is_cpuat91()	(0)
#endif

#ifdef CONFIG_MACH_IQ81340SC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ81340SC
# endif
# define machine_is_iq81340sc()	(machine_arch_type == MACH_TYPE_IQ81340SC)
#else
# define machine_is_iq81340sc()	(0)
#endif

#ifdef CONFIG_MACH_IQ81340MC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ81340MC
# endif
# define machine_is_iq81340mc()	(machine_arch_type == MACH_TYPE_IQ81340MC)
#else
# define machine_is_iq81340mc()	(0)
#endif

#ifdef CONFIG_MACH_SE4200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SE4200
# endif
# define machine_is_se4200()	(machine_arch_type == MACH_TYPE_SE4200)
#else
# define machine_is_se4200()	(0)
#endif

#ifdef CONFIG_MACH_MICRO9
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MICRO9
# endif
# define machine_is_micro9()	(machine_arch_type == MACH_TYPE_MICRO9)
#else
# define machine_is_micro9()	(0)
#endif

#ifdef CONFIG_MACH_MICRO9L
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MICRO9L
# endif
# define machine_is_micro9l()	(machine_arch_type == MACH_TYPE_MICRO9L)
#else
# define machine_is_micro9l()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_PALMTE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_PALMTE
# endif
# define machine_is_omap_palmte()	(machine_arch_type == MACH_TYPE_OMAP_PALMTE)
#else
# define machine_is_omap_palmte()	(0)
#endif

#ifdef CONFIG_MACH_REALVIEW_EB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REALVIEW_EB
# endif
# define machine_is_realview_eb()	(machine_arch_type == MACH_TYPE_REALVIEW_EB)
#else
# define machine_is_realview_eb()	(0)
#endif

#ifdef CONFIG_MACH_BORZOI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BORZOI
# endif
# define machine_is_borzoi()	(machine_arch_type == MACH_TYPE_BORZOI)
#else
# define machine_is_borzoi()	(0)
#endif

#ifdef CONFIG_MACH_PALMLD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PALMLD
# endif
# define machine_is_palmld()	(machine_arch_type == MACH_TYPE_PALMLD)
#else
# define machine_is_palmld()	(0)
#endif

#ifdef CONFIG_MACH_IXDP28X5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP28X5
# endif
# define machine_is_ixdp28x5()	(machine_arch_type == MACH_TYPE_IXDP28X5)
#else
# define machine_is_ixdp28x5()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_PALMTT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_PALMTT
# endif
# define machine_is_omap_palmtt()	(machine_arch_type == MACH_TYPE_OMAP_PALMTT)
#else
# define machine_is_omap_palmtt()	(0)
#endif

#ifdef CONFIG_MACH_ARCOM_ZEUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARCOM_ZEUS
# endif
# define machine_is_arcom_zeus()	(machine_arch_type == MACH_TYPE_ARCOM_ZEUS)
#else
# define machine_is_arcom_zeus()	(0)
#endif

#ifdef CONFIG_MACH_OSIRIS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OSIRIS
# endif
# define machine_is_osiris()	(machine_arch_type == MACH_TYPE_OSIRIS)
#else
# define machine_is_osiris()	(0)
#endif

#ifdef CONFIG_MACH_PALMTE2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PALMTE2
# endif
# define machine_is_palmte2()	(machine_arch_type == MACH_TYPE_PALMTE2)
#else
# define machine_is_palmte2()	(0)
#endif

#ifdef CONFIG_MACH_MX27ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX27ADS
# endif
# define machine_is_mx27ads()	(machine_arch_type == MACH_TYPE_MX27ADS)
#else
# define machine_is_mx27ads()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9261EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9261EK
# endif
# define machine_is_at91sam9261ek()	(machine_arch_type == MACH_TYPE_AT91SAM9261EK)
#else
# define machine_is_at91sam9261ek()	(0)
#endif

#ifdef CONFIG_MACH_LOFT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LOFT
# endif
# define machine_is_loft()	(machine_arch_type == MACH_TYPE_LOFT)
#else
# define machine_is_loft()	(0)
#endif

#ifdef CONFIG_MACH_MX21ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX21ADS
# endif
# define machine_is_mx21ads()	(machine_arch_type == MACH_TYPE_MX21ADS)
#else
# define machine_is_mx21ads()	(0)
#endif

#ifdef CONFIG_MACH_AMS_DELTA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AMS_DELTA
# endif
# define machine_is_ams_delta()	(machine_arch_type == MACH_TYPE_AMS_DELTA)
#else
# define machine_is_ams_delta()	(0)
#endif

#ifdef CONFIG_MACH_NAS100D
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NAS100D
# endif
# define machine_is_nas100d()	(machine_arch_type == MACH_TYPE_NAS100D)
#else
# define machine_is_nas100d()	(0)
#endif

#ifdef CONFIG_MACH_MAGICIAN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MAGICIAN
# endif
# define machine_is_magician()	(machine_arch_type == MACH_TYPE_MAGICIAN)
#else
# define machine_is_magician()	(0)
#endif

#ifdef CONFIG_MACH_CM4002
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM4002
# endif
# define machine_is_cm4002()	(machine_arch_type == MACH_TYPE_CM4002)
#else
# define machine_is_cm4002()	(0)
#endif

#ifdef CONFIG_MACH_NXDKN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NXDKN
# endif
# define machine_is_nxdkn()	(machine_arch_type == MACH_TYPE_NXDKN)
#else
# define machine_is_nxdkn()	(0)
#endif

#ifdef CONFIG_MACH_PALMTX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PALMTX
# endif
# define machine_is_palmtx()	(machine_arch_type == MACH_TYPE_PALMTX)
#else
# define machine_is_palmtx()	(0)
#endif

#ifdef CONFIG_MACH_S3C2413
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C2413
# endif
# define machine_is_s3c2413()	(machine_arch_type == MACH_TYPE_S3C2413)
#else
# define machine_is_s3c2413()	(0)
#endif

#ifdef CONFIG_MACH_WG302V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WG302V2
# endif
# define machine_is_wg302v2()	(machine_arch_type == MACH_TYPE_WG302V2)
#else
# define machine_is_wg302v2()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_2430SDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_2430SDP
# endif
# define machine_is_omap_2430sdp()	(machine_arch_type == MACH_TYPE_OMAP_2430SDP)
#else
# define machine_is_omap_2430sdp()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_EVM
# endif
# define machine_is_davinci_evm()	(machine_arch_type == MACH_TYPE_DAVINCI_EVM)
#else
# define machine_is_davinci_evm()	(0)
#endif

#ifdef CONFIG_MACH_PALMZ72
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PALMZ72
# endif
# define machine_is_palmz72()	(machine_arch_type == MACH_TYPE_PALMZ72)
#else
# define machine_is_palmz72()	(0)
#endif

#ifdef CONFIG_MACH_NXDB500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NXDB500
# endif
# define machine_is_nxdb500()	(machine_arch_type == MACH_TYPE_NXDB500)
#else
# define machine_is_nxdb500()	(0)
#endif

#ifdef CONFIG_MACH_APF9328
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_APF9328
# endif
# define machine_is_apf9328()	(machine_arch_type == MACH_TYPE_APF9328)
#else
# define machine_is_apf9328()	(0)
#endif

#ifdef CONFIG_MACH_PALMT5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PALMT5
# endif
# define machine_is_palmt5()	(machine_arch_type == MACH_TYPE_PALMT5)
#else
# define machine_is_palmt5()	(0)
#endif

#ifdef CONFIG_MACH_PALMTC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PALMTC
# endif
# define machine_is_palmtc()	(machine_arch_type == MACH_TYPE_PALMTC)
#else
# define machine_is_palmtc()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_APOLLON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_APOLLON
# endif
# define machine_is_omap_apollon()	(machine_arch_type == MACH_TYPE_OMAP_APOLLON)
#else
# define machine_is_omap_apollon()	(0)
#endif

#ifdef CONFIG_MACH_ATEB9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ATEB9200
# endif
# define machine_is_ateb9200()	(machine_arch_type == MACH_TYPE_ATEB9200)
#else
# define machine_is_ateb9200()	(0)
#endif

#ifdef CONFIG_MACH_N35
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_N35
# endif
# define machine_is_n35()	(machine_arch_type == MACH_TYPE_N35)
#else
# define machine_is_n35()	(0)
#endif

#ifdef CONFIG_MACH_LOGICPD_PXA270
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LOGICPD_PXA270
# endif
# define machine_is_logicpd_pxa270()	(machine_arch_type == MACH_TYPE_LOGICPD_PXA270)
#else
# define machine_is_logicpd_pxa270()	(0)
#endif

#ifdef CONFIG_MACH_NXEB500HMI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NXEB500HMI
# endif
# define machine_is_nxeb500hmi()	(machine_arch_type == MACH_TYPE_NXEB500HMI)
#else
# define machine_is_nxeb500hmi()	(0)
#endif

#ifdef CONFIG_MACH_ESPRESSO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESPRESSO
# endif
# define machine_is_espresso()	(machine_arch_type == MACH_TYPE_ESPRESSO)
#else
# define machine_is_espresso()	(0)
#endif

#ifdef CONFIG_MACH_RX1950
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RX1950
# endif
# define machine_is_rx1950()	(machine_arch_type == MACH_TYPE_RX1950)
#else
# define machine_is_rx1950()	(0)
#endif

#ifdef CONFIG_MACH_GESBC9312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GESBC9312
# endif
# define machine_is_gesbc9312()	(machine_arch_type == MACH_TYPE_GESBC9312)
#else
# define machine_is_gesbc9312()	(0)
#endif

#ifdef CONFIG_MACH_PICOTUX2XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PICOTUX2XX
# endif
# define machine_is_picotux2xx()	(machine_arch_type == MACH_TYPE_PICOTUX2XX)
#else
# define machine_is_picotux2xx()	(0)
#endif

#ifdef CONFIG_MACH_DSMG600
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DSMG600
# endif
# define machine_is_dsmg600()	(machine_arch_type == MACH_TYPE_DSMG600)
#else
# define machine_is_dsmg600()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_FSAMPLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_FSAMPLE
# endif
# define machine_is_omap_fsample()	(machine_arch_type == MACH_TYPE_OMAP_FSAMPLE)
#else
# define machine_is_omap_fsample()	(0)
#endif

#ifdef CONFIG_MACH_SNAPPER_CL15
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SNAPPER_CL15
# endif
# define machine_is_snapper_cl15()	(machine_arch_type == MACH_TYPE_SNAPPER_CL15)
#else
# define machine_is_snapper_cl15()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_PALMZ71
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_PALMZ71
# endif
# define machine_is_omap_palmz71()	(machine_arch_type == MACH_TYPE_OMAP_PALMZ71)
#else
# define machine_is_omap_palmz71()	(0)
#endif

#ifdef CONFIG_MACH_SMDK2412
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2412
# endif
# define machine_is_smdk2412()	(machine_arch_type == MACH_TYPE_SMDK2412)
#else
# define machine_is_smdk2412()	(0)
#endif

#ifdef CONFIG_MACH_SMDK2413
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2413
# endif
# define machine_is_smdk2413()	(machine_arch_type == MACH_TYPE_SMDK2413)
#else
# define machine_is_smdk2413()	(0)
#endif

#ifdef CONFIG_MACH_AML_M5900
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AML_M5900
# endif
# define machine_is_aml_m5900()	(machine_arch_type == MACH_TYPE_AML_M5900)
#else
# define machine_is_aml_m5900()	(0)
#endif

#ifdef CONFIG_MACH_BALLOON3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BALLOON3
# endif
# define machine_is_balloon3()	(machine_arch_type == MACH_TYPE_BALLOON3)
#else
# define machine_is_balloon3()	(0)
#endif

#ifdef CONFIG_MACH_ECBAT91
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ECBAT91
# endif
# define machine_is_ecbat91()	(machine_arch_type == MACH_TYPE_ECBAT91)
#else
# define machine_is_ecbat91()	(0)
#endif

#ifdef CONFIG_MACH_ONEARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ONEARM
# endif
# define machine_is_onearm()	(machine_arch_type == MACH_TYPE_ONEARM)
#else
# define machine_is_onearm()	(0)
#endif

#ifdef CONFIG_MACH_SMDK2443
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2443
# endif
# define machine_is_smdk2443()	(machine_arch_type == MACH_TYPE_SMDK2443)
#else
# define machine_is_smdk2443()	(0)
#endif

#ifdef CONFIG_MACH_FSG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FSG
# endif
# define machine_is_fsg()	(machine_arch_type == MACH_TYPE_FSG)
#else
# define machine_is_fsg()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9260EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9260EK
# endif
# define machine_is_at91sam9260ek()	(machine_arch_type == MACH_TYPE_AT91SAM9260EK)
#else
# define machine_is_at91sam9260ek()	(0)
#endif

#ifdef CONFIG_MACH_GLANTANK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GLANTANK
# endif
# define machine_is_glantank()	(machine_arch_type == MACH_TYPE_GLANTANK)
#else
# define machine_is_glantank()	(0)
#endif

#ifdef CONFIG_MACH_N2100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_N2100
# endif
# define machine_is_n2100()	(machine_arch_type == MACH_TYPE_N2100)
#else
# define machine_is_n2100()	(0)
#endif

#ifdef CONFIG_MACH_IM42XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IM42XX
# endif
# define machine_is_im42xx()	(machine_arch_type == MACH_TYPE_IM42XX)
#else
# define machine_is_im42xx()	(0)
#endif

#ifdef CONFIG_MACH_QT2410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QT2410
# endif
# define machine_is_qt2410()	(machine_arch_type == MACH_TYPE_QT2410)
#else
# define machine_is_qt2410()	(0)
#endif

#ifdef CONFIG_MACH_KIXRP435
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KIXRP435
# endif
# define machine_is_kixrp435()	(machine_arch_type == MACH_TYPE_KIXRP435)
#else
# define machine_is_kixrp435()	(0)
#endif

#ifdef CONFIG_MACH_CC9P9360DEV
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CC9P9360DEV
# endif
# define machine_is_cc9p9360dev()	(machine_arch_type == MACH_TYPE_CC9P9360DEV)
#else
# define machine_is_cc9p9360dev()	(0)
#endif

#ifdef CONFIG_MACH_EDB9302A
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9302A
# endif
# define machine_is_edb9302a()	(machine_arch_type == MACH_TYPE_EDB9302A)
#else
# define machine_is_edb9302a()	(0)
#endif

#ifdef CONFIG_MACH_EDB9307A
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9307A
# endif
# define machine_is_edb9307a()	(machine_arch_type == MACH_TYPE_EDB9307A)
#else
# define machine_is_edb9307a()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_3430SDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_3430SDP
# endif
# define machine_is_omap_3430sdp()	(machine_arch_type == MACH_TYPE_OMAP_3430SDP)
#else
# define machine_is_omap_3430sdp()	(0)
#endif

#ifdef CONFIG_MACH_VSTMS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VSTMS
# endif
# define machine_is_vstms()	(machine_arch_type == MACH_TYPE_VSTMS)
#else
# define machine_is_vstms()	(0)
#endif

#ifdef CONFIG_MACH_MICRO9M
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MICRO9M
# endif
# define machine_is_micro9m()	(machine_arch_type == MACH_TYPE_MICRO9M)
#else
# define machine_is_micro9m()	(0)
#endif

#ifdef CONFIG_MACH_BUG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BUG
# endif
# define machine_is_bug()	(machine_arch_type == MACH_TYPE_BUG)
#else
# define machine_is_bug()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9263EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9263EK
# endif
# define machine_is_at91sam9263ek()	(machine_arch_type == MACH_TYPE_AT91SAM9263EK)
#else
# define machine_is_at91sam9263ek()	(0)
#endif

#ifdef CONFIG_MACH_EM7210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EM7210
# endif
# define machine_is_em7210()	(machine_arch_type == MACH_TYPE_EM7210)
#else
# define machine_is_em7210()	(0)
#endif

#ifdef CONFIG_MACH_VPAC270
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VPAC270
# endif
# define machine_is_vpac270()	(machine_arch_type == MACH_TYPE_VPAC270)
#else
# define machine_is_vpac270()	(0)
#endif

#ifdef CONFIG_MACH_TREO680
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TREO680
# endif
# define machine_is_treo680()	(machine_arch_type == MACH_TYPE_TREO680)
#else
# define machine_is_treo680()	(0)
#endif

#ifdef CONFIG_MACH_ZYLONITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ZYLONITE
# endif
# define machine_is_zylonite()	(machine_arch_type == MACH_TYPE_ZYLONITE)
#else
# define machine_is_zylonite()	(0)
#endif

#ifdef CONFIG_MACH_MX31LITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX31LITE
# endif
# define machine_is_mx31lite()	(machine_arch_type == MACH_TYPE_MX31LITE)
#else
# define machine_is_mx31lite()	(0)
#endif

#ifdef CONFIG_MACH_MIOA701
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MIOA701
# endif
# define machine_is_mioa701()	(machine_arch_type == MACH_TYPE_MIOA701)
#else
# define machine_is_mioa701()	(0)
#endif

#ifdef CONFIG_MACH_ARMADILLO5X0
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMADILLO5X0
# endif
# define machine_is_armadillo5x0()	(machine_arch_type == MACH_TYPE_ARMADILLO5X0)
#else
# define machine_is_armadillo5x0()	(0)
#endif

#ifdef CONFIG_MACH_CC9P9360JS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CC9P9360JS
# endif
# define machine_is_cc9p9360js()	(machine_arch_type == MACH_TYPE_CC9P9360JS)
#else
# define machine_is_cc9p9360js()	(0)
#endif

#ifdef CONFIG_MACH_SMDK6400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK6400
# endif
# define machine_is_smdk6400()	(machine_arch_type == MACH_TYPE_SMDK6400)
#else
# define machine_is_smdk6400()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA_N800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA_N800
# endif
# define machine_is_nokia_n800()	(machine_arch_type == MACH_TYPE_NOKIA_N800)
#else
# define machine_is_nokia_n800()	(0)
#endif

#ifdef CONFIG_MACH_EP80219
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EP80219
# endif
# define machine_is_ep80219()	(machine_arch_type == MACH_TYPE_EP80219)
#else
# define machine_is_ep80219()	(0)
#endif

#ifdef CONFIG_MACH_GORAMO_MLR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GORAMO_MLR
# endif
# define machine_is_goramo_mlr()	(machine_arch_type == MACH_TYPE_GORAMO_MLR)
#else
# define machine_is_goramo_mlr()	(0)
#endif

#ifdef CONFIG_MACH_EM_X270
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EM_X270
# endif
# define machine_is_em_x270()	(machine_arch_type == MACH_TYPE_EM_X270)
#else
# define machine_is_em_x270()	(0)
#endif

#ifdef CONFIG_MACH_NEO1973_GTA02
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEO1973_GTA02
# endif
# define machine_is_neo1973_gta02()	(machine_arch_type == MACH_TYPE_NEO1973_GTA02)
#else
# define machine_is_neo1973_gta02()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9RLEK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9RLEK
# endif
# define machine_is_at91sam9rlek()	(machine_arch_type == MACH_TYPE_AT91SAM9RLEK)
#else
# define machine_is_at91sam9rlek()	(0)
#endif

#ifdef CONFIG_MACH_COLIBRI320
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COLIBRI320
# endif
# define machine_is_colibri320()	(machine_arch_type == MACH_TYPE_COLIBRI320)
#else
# define machine_is_colibri320()	(0)
#endif

#ifdef CONFIG_MACH_CAM60
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CAM60
# endif
# define machine_is_cam60()	(machine_arch_type == MACH_TYPE_CAM60)
#else
# define machine_is_cam60()	(0)
#endif

#ifdef CONFIG_MACH_AT91EB01
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91EB01
# endif
# define machine_is_at91eb01()	(machine_arch_type == MACH_TYPE_AT91EB01)
#else
# define machine_is_at91eb01()	(0)
#endif

#ifdef CONFIG_MACH_DB88F5281
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DB88F5281
# endif
# define machine_is_db88f5281()	(machine_arch_type == MACH_TYPE_DB88F5281)
#else
# define machine_is_db88f5281()	(0)
#endif

#ifdef CONFIG_MACH_CSB726
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSB726
# endif
# define machine_is_csb726()	(machine_arch_type == MACH_TYPE_CSB726)
#else
# define machine_is_csb726()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_DM6467_EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_DM6467_EVM
# endif
# define machine_is_davinci_dm6467_evm()	(machine_arch_type == MACH_TYPE_DAVINCI_DM6467_EVM)
#else
# define machine_is_davinci_dm6467_evm()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_DM355_EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_DM355_EVM
# endif
# define machine_is_davinci_dm355_evm()	(machine_arch_type == MACH_TYPE_DAVINCI_DM355_EVM)
#else
# define machine_is_davinci_dm355_evm()	(0)
#endif

#ifdef CONFIG_MACH_LITTLETON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LITTLETON
# endif
# define machine_is_littleton()	(machine_arch_type == MACH_TYPE_LITTLETON)
#else
# define machine_is_littleton()	(0)
#endif

#ifdef CONFIG_MACH_IM4004
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IM4004
# endif
# define machine_is_im4004()	(machine_arch_type == MACH_TYPE_IM4004)
#else
# define machine_is_im4004()	(0)
#endif

#ifdef CONFIG_MACH_REALVIEW_PB11MP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REALVIEW_PB11MP
# endif
# define machine_is_realview_pb11mp()	(machine_arch_type == MACH_TYPE_REALVIEW_PB11MP)
#else
# define machine_is_realview_pb11mp()	(0)
#endif

#ifdef CONFIG_MACH_MX27_3DS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX27_3DS
# endif
# define machine_is_mx27_3ds()	(machine_arch_type == MACH_TYPE_MX27_3DS)
#else
# define machine_is_mx27_3ds()	(0)
#endif

#ifdef CONFIG_MACH_HALIBUT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HALIBUT
# endif
# define machine_is_halibut()	(machine_arch_type == MACH_TYPE_HALIBUT)
#else
# define machine_is_halibut()	(0)
#endif

#ifdef CONFIG_MACH_TROUT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TROUT
# endif
# define machine_is_trout()	(machine_arch_type == MACH_TYPE_TROUT)
#else
# define machine_is_trout()	(0)
#endif

#ifdef CONFIG_MACH_TCT_HAMMER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TCT_HAMMER
# endif
# define machine_is_tct_hammer()	(machine_arch_type == MACH_TYPE_TCT_HAMMER)
#else
# define machine_is_tct_hammer()	(0)
#endif

#ifdef CONFIG_MACH_HERALD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HERALD
# endif
# define machine_is_herald()	(machine_arch_type == MACH_TYPE_HERALD)
#else
# define machine_is_herald()	(0)
#endif

#ifdef CONFIG_MACH_SIM_ONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIM_ONE
# endif
# define machine_is_sim_one()	(machine_arch_type == MACH_TYPE_SIM_ONE)
#else
# define machine_is_sim_one()	(0)
#endif

#ifdef CONFIG_MACH_JIVE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JIVE
# endif
# define machine_is_jive()	(machine_arch_type == MACH_TYPE_JIVE)
#else
# define machine_is_jive()	(0)
#endif

#ifdef CONFIG_MACH_SAM9_L9260
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SAM9_L9260
# endif
# define machine_is_sam9_l9260()	(machine_arch_type == MACH_TYPE_SAM9_L9260)
#else
# define machine_is_sam9_l9260()	(0)
#endif

#ifdef CONFIG_MACH_REALVIEW_PB1176
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REALVIEW_PB1176
# endif
# define machine_is_realview_pb1176()	(machine_arch_type == MACH_TYPE_REALVIEW_PB1176)
#else
# define machine_is_realview_pb1176()	(0)
#endif

#ifdef CONFIG_MACH_YL9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_YL9200
# endif
# define machine_is_yl9200()	(machine_arch_type == MACH_TYPE_YL9200)
#else
# define machine_is_yl9200()	(0)
#endif

#ifdef CONFIG_MACH_RD88F5182
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD88F5182
# endif
# define machine_is_rd88f5182()	(machine_arch_type == MACH_TYPE_RD88F5182)
#else
# define machine_is_rd88f5182()	(0)
#endif

#ifdef CONFIG_MACH_KUROBOX_PRO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KUROBOX_PRO
# endif
# define machine_is_kurobox_pro()	(machine_arch_type == MACH_TYPE_KUROBOX_PRO)
#else
# define machine_is_kurobox_pro()	(0)
#endif

#ifdef CONFIG_MACH_MX31_3DS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX31_3DS
# endif
# define machine_is_mx31_3ds()	(machine_arch_type == MACH_TYPE_MX31_3DS)
#else
# define machine_is_mx31_3ds()	(0)
#endif

#ifdef CONFIG_MACH_QONG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QONG
# endif
# define machine_is_qong()	(machine_arch_type == MACH_TYPE_QONG)
#else
# define machine_is_qong()	(0)
#endif

#ifdef CONFIG_MACH_OMAP2EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP2EVM
# endif
# define machine_is_omap2evm()	(machine_arch_type == MACH_TYPE_OMAP2EVM)
#else
# define machine_is_omap2evm()	(0)
#endif

#ifdef CONFIG_MACH_OMAP3EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP3EVM
# endif
# define machine_is_omap3evm()	(machine_arch_type == MACH_TYPE_OMAP3EVM)
#else
# define machine_is_omap3evm()	(0)
#endif

#ifdef CONFIG_MACH_DNS323
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DNS323
# endif
# define machine_is_dns323()	(machine_arch_type == MACH_TYPE_DNS323)
#else
# define machine_is_dns323()	(0)
#endif

#ifdef CONFIG_MACH_OMAP3_BEAGLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP3_BEAGLE
# endif
# define machine_is_omap3_beagle()	(machine_arch_type == MACH_TYPE_OMAP3_BEAGLE)
#else
# define machine_is_omap3_beagle()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA_N810
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA_N810
# endif
# define machine_is_nokia_n810()	(machine_arch_type == MACH_TYPE_NOKIA_N810)
#else
# define machine_is_nokia_n810()	(0)
#endif

#ifdef CONFIG_MACH_PCM038
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCM038
# endif
# define machine_is_pcm038()	(machine_arch_type == MACH_TYPE_PCM038)
#else
# define machine_is_pcm038()	(0)
#endif

#ifdef CONFIG_MACH_SG310
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SG310
# endif
# define machine_is_sg310()	(machine_arch_type == MACH_TYPE_SG310)
#else
# define machine_is_sg310()	(0)
#endif

#ifdef CONFIG_MACH_TS209
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TS209
# endif
# define machine_is_ts209()	(machine_arch_type == MACH_TYPE_TS209)
#else
# define machine_is_ts209()	(0)
#endif

#ifdef CONFIG_MACH_AT91CAP9ADK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91CAP9ADK
# endif
# define machine_is_at91cap9adk()	(machine_arch_type == MACH_TYPE_AT91CAP9ADK)
#else
# define machine_is_at91cap9adk()	(0)
#endif

#ifdef CONFIG_MACH_MX31MOBOARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX31MOBOARD
# endif
# define machine_is_mx31moboard()	(machine_arch_type == MACH_TYPE_MX31MOBOARD)
#else
# define machine_is_mx31moboard()	(0)
#endif

#ifdef CONFIG_MACH_VISION_EP9307
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VISION_EP9307
# endif
# define machine_is_vision_ep9307()	(machine_arch_type == MACH_TYPE_VISION_EP9307)
#else
# define machine_is_vision_ep9307()	(0)
#endif

#ifdef CONFIG_MACH_TERASTATION_PRO2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TERASTATION_PRO2
# endif
# define machine_is_terastation_pro2()	(machine_arch_type == MACH_TYPE_TERASTATION_PRO2)
#else
# define machine_is_terastation_pro2()	(0)
#endif

#ifdef CONFIG_MACH_LINKSTATION_PRO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LINKSTATION_PRO
# endif
# define machine_is_linkstation_pro()	(machine_arch_type == MACH_TYPE_LINKSTATION_PRO)
#else
# define machine_is_linkstation_pro()	(0)
#endif

#ifdef CONFIG_MACH_E350
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E350
# endif
# define machine_is_e350()	(machine_arch_type == MACH_TYPE_E350)
#else
# define machine_is_e350()	(0)
#endif

#ifdef CONFIG_MACH_TS409
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TS409
# endif
# define machine_is_ts409()	(machine_arch_type == MACH_TYPE_TS409)
#else
# define machine_is_ts409()	(0)
#endif

#ifdef CONFIG_MACH_RSI_EWS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RSI_EWS
# endif
# define machine_is_rsi_ews()	(machine_arch_type == MACH_TYPE_RSI_EWS)
#else
# define machine_is_rsi_ews()	(0)
#endif

#ifdef CONFIG_MACH_CM_X300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM_X300
# endif
# define machine_is_cm_x300()	(machine_arch_type == MACH_TYPE_CM_X300)
#else
# define machine_is_cm_x300()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9G20EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9G20EK
# endif
# define machine_is_at91sam9g20ek()	(machine_arch_type == MACH_TYPE_AT91SAM9G20EK)
#else
# define machine_is_at91sam9g20ek()	(0)
#endif

#ifdef CONFIG_MACH_SMDK6410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK6410
# endif
# define machine_is_smdk6410()	(machine_arch_type == MACH_TYPE_SMDK6410)
#else
# define machine_is_smdk6410()	(0)
#endif

#ifdef CONFIG_MACH_U300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_U300
# endif
# define machine_is_u300()	(machine_arch_type == MACH_TYPE_U300)
#else
# define machine_is_u300()	(0)
#endif

#ifdef CONFIG_MACH_WRT350N_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WRT350N_V2
# endif
# define machine_is_wrt350n_v2()	(machine_arch_type == MACH_TYPE_WRT350N_V2)
#else
# define machine_is_wrt350n_v2()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_LDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_LDP
# endif
# define machine_is_omap_ldp()	(machine_arch_type == MACH_TYPE_OMAP_LDP)
#else
# define machine_is_omap_ldp()	(0)
#endif

#ifdef CONFIG_MACH_MX35_3DS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX35_3DS
# endif
# define machine_is_mx35_3ds()	(machine_arch_type == MACH_TYPE_MX35_3DS)
#else
# define machine_is_mx35_3ds()	(0)
#endif

#ifdef CONFIG_MACH_NEUROS_OSD2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEUROS_OSD2
# endif
# define machine_is_neuros_osd2()	(machine_arch_type == MACH_TYPE_NEUROS_OSD2)
#else
# define machine_is_neuros_osd2()	(0)
#endif

#ifdef CONFIG_MACH_TRIZEPS4WL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TRIZEPS4WL
# endif
# define machine_is_trizeps4wl()	(machine_arch_type == MACH_TYPE_TRIZEPS4WL)
#else
# define machine_is_trizeps4wl()	(0)
#endif

#ifdef CONFIG_MACH_TS78XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TS78XX
# endif
# define machine_is_ts78xx()	(machine_arch_type == MACH_TYPE_TS78XX)
#else
# define machine_is_ts78xx()	(0)
#endif

#ifdef CONFIG_MACH_SFFSDR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SFFSDR
# endif
# define machine_is_sffsdr()	(machine_arch_type == MACH_TYPE_SFFSDR)
#else
# define machine_is_sffsdr()	(0)
#endif

#ifdef CONFIG_MACH_PCM037
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCM037
# endif
# define machine_is_pcm037()	(machine_arch_type == MACH_TYPE_PCM037)
#else
# define machine_is_pcm037()	(0)
#endif

#ifdef CONFIG_MACH_DB88F6281_BP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DB88F6281_BP
# endif
# define machine_is_db88f6281_bp()	(machine_arch_type == MACH_TYPE_DB88F6281_BP)
#else
# define machine_is_db88f6281_bp()	(0)
#endif

#ifdef CONFIG_MACH_RD88F6192_NAS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD88F6192_NAS
# endif
# define machine_is_rd88f6192_nas()	(machine_arch_type == MACH_TYPE_RD88F6192_NAS)
#else
# define machine_is_rd88f6192_nas()	(0)
#endif

#ifdef CONFIG_MACH_RD88F6281
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD88F6281
# endif
# define machine_is_rd88f6281()	(machine_arch_type == MACH_TYPE_RD88F6281)
#else
# define machine_is_rd88f6281()	(0)
#endif

#ifdef CONFIG_MACH_DB78X00_BP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DB78X00_BP
# endif
# define machine_is_db78x00_bp()	(machine_arch_type == MACH_TYPE_DB78X00_BP)
#else
# define machine_is_db78x00_bp()	(0)
#endif

#ifdef CONFIG_MACH_SMDK2416
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2416
# endif
# define machine_is_smdk2416()	(machine_arch_type == MACH_TYPE_SMDK2416)
#else
# define machine_is_smdk2416()	(0)
#endif

#ifdef CONFIG_MACH_WBD111
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WBD111
# endif
# define machine_is_wbd111()	(machine_arch_type == MACH_TYPE_WBD111)
#else
# define machine_is_wbd111()	(0)
#endif

#ifdef CONFIG_MACH_MV2120
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MV2120
# endif
# define machine_is_mv2120()	(machine_arch_type == MACH_TYPE_MV2120)
#else
# define machine_is_mv2120()	(0)
#endif

#ifdef CONFIG_MACH_MX51_3DS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX51_3DS
# endif
# define machine_is_mx51_3ds()	(machine_arch_type == MACH_TYPE_MX51_3DS)
#else
# define machine_is_mx51_3ds()	(0)
#endif

#ifdef CONFIG_MACH_IMX27LITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IMX27LITE
# endif
# define machine_is_imx27lite()	(machine_arch_type == MACH_TYPE_IMX27LITE)
#else
# define machine_is_imx27lite()	(0)
#endif

#ifdef CONFIG_MACH_USB_A9260
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_USB_A9260
# endif
# define machine_is_usb_a9260()	(machine_arch_type == MACH_TYPE_USB_A9260)
#else
# define machine_is_usb_a9260()	(0)
#endif

#ifdef CONFIG_MACH_USB_A9263
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_USB_A9263
# endif
# define machine_is_usb_a9263()	(machine_arch_type == MACH_TYPE_USB_A9263)
#else
# define machine_is_usb_a9263()	(0)
#endif

#ifdef CONFIG_MACH_QIL_A9260
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QIL_A9260
# endif
# define machine_is_qil_a9260()	(machine_arch_type == MACH_TYPE_QIL_A9260)
#else
# define machine_is_qil_a9260()	(0)
#endif

#ifdef CONFIG_MACH_KZM_ARM11_01
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KZM_ARM11_01
# endif
# define machine_is_kzm_arm11_01()	(machine_arch_type == MACH_TYPE_KZM_ARM11_01)
#else
# define machine_is_kzm_arm11_01()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA_N810_WIMAX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA_N810_WIMAX
# endif
# define machine_is_nokia_n810_wimax()	(machine_arch_type == MACH_TYPE_NOKIA_N810_WIMAX)
#else
# define machine_is_nokia_n810_wimax()	(0)
#endif

#ifdef CONFIG_MACH_SAPPHIRE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SAPPHIRE
# endif
# define machine_is_sapphire()	(machine_arch_type == MACH_TYPE_SAPPHIRE)
#else
# define machine_is_sapphire()	(0)
#endif

#ifdef CONFIG_MACH_STMP37XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STMP37XX
# endif
# define machine_is_stmp37xx()	(machine_arch_type == MACH_TYPE_STMP37XX)
#else
# define machine_is_stmp37xx()	(0)
#endif

#ifdef CONFIG_MACH_STMP378X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STMP378X
# endif
# define machine_is_stmp378x()	(machine_arch_type == MACH_TYPE_STMP378X)
#else
# define machine_is_stmp378x()	(0)
#endif

#ifdef CONFIG_MACH_EZX_A780
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZX_A780
# endif
# define machine_is_ezx_a780()	(machine_arch_type == MACH_TYPE_EZX_A780)
#else
# define machine_is_ezx_a780()	(0)
#endif

#ifdef CONFIG_MACH_EZX_E680
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZX_E680
# endif
# define machine_is_ezx_e680()	(machine_arch_type == MACH_TYPE_EZX_E680)
#else
# define machine_is_ezx_e680()	(0)
#endif

#ifdef CONFIG_MACH_EZX_A1200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZX_A1200
# endif
# define machine_is_ezx_a1200()	(machine_arch_type == MACH_TYPE_EZX_A1200)
#else
# define machine_is_ezx_a1200()	(0)
#endif

#ifdef CONFIG_MACH_EZX_E6
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZX_E6
# endif
# define machine_is_ezx_e6()	(machine_arch_type == MACH_TYPE_EZX_E6)
#else
# define machine_is_ezx_e6()	(0)
#endif

#ifdef CONFIG_MACH_EZX_E2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZX_E2
# endif
# define machine_is_ezx_e2()	(machine_arch_type == MACH_TYPE_EZX_E2)
#else
# define machine_is_ezx_e2()	(0)
#endif

#ifdef CONFIG_MACH_EZX_A910
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZX_A910
# endif
# define machine_is_ezx_a910()	(machine_arch_type == MACH_TYPE_EZX_A910)
#else
# define machine_is_ezx_a910()	(0)
#endif

#ifdef CONFIG_MACH_EDMINI_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDMINI_V2
# endif
# define machine_is_edmini_v2()	(machine_arch_type == MACH_TYPE_EDMINI_V2)
#else
# define machine_is_edmini_v2()	(0)
#endif

#ifdef CONFIG_MACH_ZIPIT2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ZIPIT2
# endif
# define machine_is_zipit2()	(machine_arch_type == MACH_TYPE_ZIPIT2)
#else
# define machine_is_zipit2()	(0)
#endif

#ifdef CONFIG_MACH_OMAP3_PANDORA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP3_PANDORA
# endif
# define machine_is_omap3_pandora()	(machine_arch_type == MACH_TYPE_OMAP3_PANDORA)
#else
# define machine_is_omap3_pandora()	(0)
#endif

#ifdef CONFIG_MACH_MSS2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSS2
# endif
# define machine_is_mss2()	(machine_arch_type == MACH_TYPE_MSS2)
#else
# define machine_is_mss2()	(0)
#endif

#ifdef CONFIG_MACH_LB88RC8480
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LB88RC8480
# endif
# define machine_is_lb88rc8480()	(machine_arch_type == MACH_TYPE_LB88RC8480)
#else
# define machine_is_lb88rc8480()	(0)
#endif

#ifdef CONFIG_MACH_MX25_3DS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX25_3DS
# endif
# define machine_is_mx25_3ds()	(machine_arch_type == MACH_TYPE_MX25_3DS)
#else
# define machine_is_mx25_3ds()	(0)
#endif

#ifdef CONFIG_MACH_OMAP3530_LV_SOM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP3530_LV_SOM
# endif
# define machine_is_omap3530_lv_som()	(machine_arch_type == MACH_TYPE_OMAP3530_LV_SOM)
#else
# define machine_is_omap3530_lv_som()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_DA830_EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_DA830_EVM
# endif
# define machine_is_davinci_da830_evm()	(machine_arch_type == MACH_TYPE_DAVINCI_DA830_EVM)
#else
# define machine_is_davinci_da830_evm()	(0)
#endif

#ifdef CONFIG_MACH_DOVE_DB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DOVE_DB
# endif
# define machine_is_dove_db()	(machine_arch_type == MACH_TYPE_DOVE_DB)
#else
# define machine_is_dove_db()	(0)
#endif

#ifdef CONFIG_MACH_OVERO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OVERO
# endif
# define machine_is_overo()	(machine_arch_type == MACH_TYPE_OVERO)
#else
# define machine_is_overo()	(0)
#endif

#ifdef CONFIG_MACH_AT2440EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT2440EVB
# endif
# define machine_is_at2440evb()	(machine_arch_type == MACH_TYPE_AT2440EVB)
#else
# define machine_is_at2440evb()	(0)
#endif

#ifdef CONFIG_MACH_NEOCORE926
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEOCORE926
# endif
# define machine_is_neocore926()	(machine_arch_type == MACH_TYPE_NEOCORE926)
#else
# define machine_is_neocore926()	(0)
#endif

#ifdef CONFIG_MACH_WNR854T
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WNR854T
# endif
# define machine_is_wnr854t()	(machine_arch_type == MACH_TYPE_WNR854T)
#else
# define machine_is_wnr854t()	(0)
#endif

#ifdef CONFIG_MACH_RD88F5181L_GE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD88F5181L_GE
# endif
# define machine_is_rd88f5181l_ge()	(machine_arch_type == MACH_TYPE_RD88F5181L_GE)
#else
# define machine_is_rd88f5181l_ge()	(0)
#endif

#ifdef CONFIG_MACH_RD88F5181L_FXO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD88F5181L_FXO
# endif
# define machine_is_rd88f5181l_fxo()	(machine_arch_type == MACH_TYPE_RD88F5181L_FXO)
#else
# define machine_is_rd88f5181l_fxo()	(0)
#endif

#ifdef CONFIG_MACH_STAMP9G20
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STAMP9G20
# endif
# define machine_is_stamp9g20()	(machine_arch_type == MACH_TYPE_STAMP9G20)
#else
# define machine_is_stamp9g20()	(0)
#endif

#ifdef CONFIG_MACH_SMDKC100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDKC100
# endif
# define machine_is_smdkc100()	(machine_arch_type == MACH_TYPE_SMDKC100)
#else
# define machine_is_smdkc100()	(0)
#endif

#ifdef CONFIG_MACH_TAVOREVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TAVOREVB
# endif
# define machine_is_tavorevb()	(machine_arch_type == MACH_TYPE_TAVOREVB)
#else
# define machine_is_tavorevb()	(0)
#endif

#ifdef CONFIG_MACH_SAAR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SAAR
# endif
# define machine_is_saar()	(machine_arch_type == MACH_TYPE_SAAR)
#else
# define machine_is_saar()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9M10G45EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9M10G45EK
# endif
# define machine_is_at91sam9m10g45ek()	(machine_arch_type == MACH_TYPE_AT91SAM9M10G45EK)
#else
# define machine_is_at91sam9m10g45ek()	(0)
#endif

#ifdef CONFIG_MACH_USB_A9G20
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_USB_A9G20
# endif
# define machine_is_usb_a9g20()	(machine_arch_type == MACH_TYPE_USB_A9G20)
#else
# define machine_is_usb_a9g20()	(0)
#endif

#ifdef CONFIG_MACH_MXLADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MXLADS
# endif
# define machine_is_mxlads()	(machine_arch_type == MACH_TYPE_MXLADS)
#else
# define machine_is_mxlads()	(0)
#endif

#ifdef CONFIG_MACH_LINKSTATION_MINI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LINKSTATION_MINI
# endif
# define machine_is_linkstation_mini()	(machine_arch_type == MACH_TYPE_LINKSTATION_MINI)
#else
# define machine_is_linkstation_mini()	(0)
#endif

#ifdef CONFIG_MACH_AFEB9260
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AFEB9260
# endif
# define machine_is_afeb9260()	(machine_arch_type == MACH_TYPE_AFEB9260)
#else
# define machine_is_afeb9260()	(0)
#endif

#ifdef CONFIG_MACH_IMX27IPCAM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IMX27IPCAM
# endif
# define machine_is_imx27ipcam()	(machine_arch_type == MACH_TYPE_IMX27IPCAM)
#else
# define machine_is_imx27ipcam()	(0)
#endif

#ifdef CONFIG_MACH_BK3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BK3
# endif
# define machine_is_bk3()	(machine_arch_type == MACH_TYPE_BK3)
#else
# define machine_is_bk3()	(0)
#endif

#ifdef CONFIG_MACH_RD88F6183AP_GE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD88F6183AP_GE
# endif
# define machine_is_rd88f6183ap_ge()	(machine_arch_type == MACH_TYPE_RD88F6183AP_GE)
#else
# define machine_is_rd88f6183ap_ge()	(0)
#endif

#ifdef CONFIG_MACH_REALVIEW_PBA8
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REALVIEW_PBA8
# endif
# define machine_is_realview_pba8()	(machine_arch_type == MACH_TYPE_REALVIEW_PBA8)
#else
# define machine_is_realview_pba8()	(0)
#endif

#ifdef CONFIG_MACH_REALVIEW_PBX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REALVIEW_PBX
# endif
# define machine_is_realview_pbx()	(machine_arch_type == MACH_TYPE_REALVIEW_PBX)
#else
# define machine_is_realview_pbx()	(0)
#endif

#ifdef CONFIG_MACH_MICRO9S
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MICRO9S
# endif
# define machine_is_micro9s()	(machine_arch_type == MACH_TYPE_MICRO9S)
#else
# define machine_is_micro9s()	(0)
#endif

#ifdef CONFIG_MACH_RUT100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RUT100
# endif
# define machine_is_rut100()	(machine_arch_type == MACH_TYPE_RUT100)
#else
# define machine_is_rut100()	(0)
#endif

#ifdef CONFIG_MACH_G3EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_G3EVM
# endif
# define machine_is_g3evm()	(machine_arch_type == MACH_TYPE_G3EVM)
#else
# define machine_is_g3evm()	(0)
#endif

#ifdef CONFIG_MACH_W90P910EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_W90P910EVB
# endif
# define machine_is_w90p910evb()	(machine_arch_type == MACH_TYPE_W90P910EVB)
#else
# define machine_is_w90p910evb()	(0)
#endif

#ifdef CONFIG_MACH_W90P950EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_W90P950EVB
# endif
# define machine_is_w90p950evb()	(machine_arch_type == MACH_TYPE_W90P950EVB)
#else
# define machine_is_w90p950evb()	(0)
#endif

#ifdef CONFIG_MACH_W90N960EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_W90N960EVB
# endif
# define machine_is_w90n960evb()	(machine_arch_type == MACH_TYPE_W90N960EVB)
#else
# define machine_is_w90n960evb()	(0)
#endif

#ifdef CONFIG_MACH_MV88F6281GTW_GE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MV88F6281GTW_GE
# endif
# define machine_is_mv88f6281gtw_ge()	(machine_arch_type == MACH_TYPE_MV88F6281GTW_GE)
#else
# define machine_is_mv88f6281gtw_ge()	(0)
#endif

#ifdef CONFIG_MACH_NCP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NCP
# endif
# define machine_is_ncp()	(machine_arch_type == MACH_TYPE_NCP)
#else
# define machine_is_ncp()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_DM365_EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_DM365_EVM
# endif
# define machine_is_davinci_dm365_evm()	(machine_arch_type == MACH_TYPE_DAVINCI_DM365_EVM)
#else
# define machine_is_davinci_dm365_evm()	(0)
#endif

#ifdef CONFIG_MACH_CENTRO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CENTRO
# endif
# define machine_is_centro()	(machine_arch_type == MACH_TYPE_CENTRO)
#else
# define machine_is_centro()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA_RX51
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA_RX51
# endif
# define machine_is_nokia_rx51()	(machine_arch_type == MACH_TYPE_NOKIA_RX51)
#else
# define machine_is_nokia_rx51()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_ZOOM2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_ZOOM2
# endif
# define machine_is_omap_zoom2()	(machine_arch_type == MACH_TYPE_OMAP_ZOOM2)
#else
# define machine_is_omap_zoom2()	(0)
#endif

#ifdef CONFIG_MACH_CPUAT9260
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CPUAT9260
# endif
# define machine_is_cpuat9260()	(machine_arch_type == MACH_TYPE_CPUAT9260)
#else
# define machine_is_cpuat9260()	(0)
#endif

#ifdef CONFIG_MACH_EUKREA_CPUIMX27
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EUKREA_CPUIMX27
# endif
# define machine_is_eukrea_cpuimx27()	(machine_arch_type == MACH_TYPE_EUKREA_CPUIMX27)
#else
# define machine_is_eukrea_cpuimx27()	(0)
#endif

#ifdef CONFIG_MACH_ACS5K
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACS5K
# endif
# define machine_is_acs5k()	(machine_arch_type == MACH_TYPE_ACS5K)
#else
# define machine_is_acs5k()	(0)
#endif

#ifdef CONFIG_MACH_SNAPPER_9260
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SNAPPER_9260
# endif
# define machine_is_snapper_9260()	(machine_arch_type == MACH_TYPE_SNAPPER_9260)
#else
# define machine_is_snapper_9260()	(0)
#endif

#ifdef CONFIG_MACH_DSM320
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DSM320
# endif
# define machine_is_dsm320()	(machine_arch_type == MACH_TYPE_DSM320)
#else
# define machine_is_dsm320()	(0)
#endif

#ifdef CONFIG_MACH_EXEDA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EXEDA
# endif
# define machine_is_exeda()	(machine_arch_type == MACH_TYPE_EXEDA)
#else
# define machine_is_exeda()	(0)
#endif

#ifdef CONFIG_MACH_MINI2440
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MINI2440
# endif
# define machine_is_mini2440()	(machine_arch_type == MACH_TYPE_MINI2440)
#else
# define machine_is_mini2440()	(0)
#endif

#ifdef CONFIG_MACH_COLIBRI300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COLIBRI300
# endif
# define machine_is_colibri300()	(machine_arch_type == MACH_TYPE_COLIBRI300)
#else
# define machine_is_colibri300()	(0)
#endif

#ifdef CONFIG_MACH_LINKSTATION_LS_HGL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LINKSTATION_LS_HGL
# endif
# define machine_is_linkstation_ls_hgl()	(machine_arch_type == MACH_TYPE_LINKSTATION_LS_HGL)
#else
# define machine_is_linkstation_ls_hgl()	(0)
#endif

#ifdef CONFIG_MACH_CPUAT9G20
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CPUAT9G20
# endif
# define machine_is_cpuat9g20()	(machine_arch_type == MACH_TYPE_CPUAT9G20)
#else
# define machine_is_cpuat9g20()	(0)
#endif

#ifdef CONFIG_MACH_SMDK6440
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK6440
# endif
# define machine_is_smdk6440()	(machine_arch_type == MACH_TYPE_SMDK6440)
#else
# define machine_is_smdk6440()	(0)
#endif

#ifdef CONFIG_MACH_NAS4220B
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NAS4220B
# endif
# define machine_is_nas4220b()	(machine_arch_type == MACH_TYPE_NAS4220B)
#else
# define machine_is_nas4220b()	(0)
#endif

#ifdef CONFIG_MACH_ZYLONITE2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ZYLONITE2
# endif
# define machine_is_zylonite2()	(machine_arch_type == MACH_TYPE_ZYLONITE2)
#else
# define machine_is_zylonite2()	(0)
#endif

#ifdef CONFIG_MACH_ASPENITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ASPENITE
# endif
# define machine_is_aspenite()	(machine_arch_type == MACH_TYPE_ASPENITE)
#else
# define machine_is_aspenite()	(0)
#endif

#ifdef CONFIG_MACH_TTC_DKB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TTC_DKB
# endif
# define machine_is_ttc_dkb()	(machine_arch_type == MACH_TYPE_TTC_DKB)
#else
# define machine_is_ttc_dkb()	(0)
#endif

#ifdef CONFIG_MACH_PCM043
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCM043
# endif
# define machine_is_pcm043()	(machine_arch_type == MACH_TYPE_PCM043)
#else
# define machine_is_pcm043()	(0)
#endif

#ifdef CONFIG_MACH_SHEEVAPLUG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHEEVAPLUG
# endif
# define machine_is_sheevaplug()	(machine_arch_type == MACH_TYPE_SHEEVAPLUG)
#else
# define machine_is_sheevaplug()	(0)
#endif

#ifdef CONFIG_MACH_AVENGERS_LITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AVENGERS_LITE
# endif
# define machine_is_avengers_lite()	(machine_arch_type == MACH_TYPE_AVENGERS_LITE)
#else
# define machine_is_avengers_lite()	(0)
#endif

#ifdef CONFIG_MACH_MX51_BABBAGE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX51_BABBAGE
# endif
# define machine_is_mx51_babbage()	(machine_arch_type == MACH_TYPE_MX51_BABBAGE)
#else
# define machine_is_mx51_babbage()	(0)
#endif

#ifdef CONFIG_MACH_RD78X00_MASA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RD78X00_MASA
# endif
# define machine_is_rd78x00_masa()	(machine_arch_type == MACH_TYPE_RD78X00_MASA)
#else
# define machine_is_rd78x00_masa()	(0)
#endif

#ifdef CONFIG_MACH_DM355_LEOPARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DM355_LEOPARD
# endif
# define machine_is_dm355_leopard()	(machine_arch_type == MACH_TYPE_DM355_LEOPARD)
#else
# define machine_is_dm355_leopard()	(0)
#endif

#ifdef CONFIG_MACH_TS219
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TS219
# endif
# define machine_is_ts219()	(machine_arch_type == MACH_TYPE_TS219)
#else
# define machine_is_ts219()	(0)
#endif

#ifdef CONFIG_MACH_PCA100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCA100
# endif
# define machine_is_pca100()	(machine_arch_type == MACH_TYPE_PCA100)
#else
# define machine_is_pca100()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_DA850_EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_DA850_EVM
# endif
# define machine_is_davinci_da850_evm()	(machine_arch_type == MACH_TYPE_DAVINCI_DA850_EVM)
#else
# define machine_is_davinci_da850_evm()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9G10EK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9G10EK
# endif
# define machine_is_at91sam9g10ek()	(machine_arch_type == MACH_TYPE_AT91SAM9G10EK)
#else
# define machine_is_at91sam9g10ek()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_4430SDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_4430SDP
# endif
# define machine_is_omap_4430sdp()	(machine_arch_type == MACH_TYPE_OMAP_4430SDP)
#else
# define machine_is_omap_4430sdp()	(0)
#endif

#ifdef CONFIG_MACH_MAGX_ZN5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MAGX_ZN5
# endif
# define machine_is_magx_zn5()	(machine_arch_type == MACH_TYPE_MAGX_ZN5)
#else
# define machine_is_magx_zn5()	(0)
#endif

#ifdef CONFIG_MACH_OMAP3_TORPEDO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP3_TORPEDO
# endif
# define machine_is_omap3_torpedo()	(machine_arch_type == MACH_TYPE_OMAP3_TORPEDO)
#else
# define machine_is_omap3_torpedo()	(0)
#endif

#ifdef CONFIG_MACH_ANW6410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ANW6410
# endif
# define machine_is_anw6410()	(machine_arch_type == MACH_TYPE_ANW6410)
#else
# define machine_is_anw6410()	(0)
#endif

#ifdef CONFIG_MACH_IMX27_VISSTRIM_M10
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IMX27_VISSTRIM_M10
# endif
# define machine_is_imx27_visstrim_m10()	(machine_arch_type == MACH_TYPE_IMX27_VISSTRIM_M10)
#else
# define machine_is_imx27_visstrim_m10()	(0)
#endif

#ifdef CONFIG_MACH_PORTUXG20
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PORTUXG20
# endif
# define machine_is_portuxg20()	(machine_arch_type == MACH_TYPE_PORTUXG20)
#else
# define machine_is_portuxg20()	(0)
#endif

#ifdef CONFIG_MACH_SMDKC110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDKC110
# endif
# define machine_is_smdkc110()	(machine_arch_type == MACH_TYPE_SMDKC110)
#else
# define machine_is_smdkc110()	(0)
#endif

#ifdef CONFIG_MACH_OMAP3517EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP3517EVM
# endif
# define machine_is_omap3517evm()	(machine_arch_type == MACH_TYPE_OMAP3517EVM)
#else
# define machine_is_omap3517evm()	(0)
#endif

#ifdef CONFIG_MACH_NETSPACE_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETSPACE_V2
# endif
# define machine_is_netspace_v2()	(machine_arch_type == MACH_TYPE_NETSPACE_V2)
#else
# define machine_is_netspace_v2()	(0)
#endif

#ifdef CONFIG_MACH_NETSPACE_MAX_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETSPACE_MAX_V2
# endif
# define machine_is_netspace_max_v2()	(machine_arch_type == MACH_TYPE_NETSPACE_MAX_V2)
#else
# define machine_is_netspace_max_v2()	(0)
#endif

#ifdef CONFIG_MACH_D2NET_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_D2NET_V2
# endif
# define machine_is_d2net_v2()	(machine_arch_type == MACH_TYPE_D2NET_V2)
#else
# define machine_is_d2net_v2()	(0)
#endif

#ifdef CONFIG_MACH_NET2BIG_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NET2BIG_V2
# endif
# define machine_is_net2big_v2()	(machine_arch_type == MACH_TYPE_NET2BIG_V2)
#else
# define machine_is_net2big_v2()	(0)
#endif

#ifdef CONFIG_MACH_NET5BIG_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NET5BIG_V2
# endif
# define machine_is_net5big_v2()	(machine_arch_type == MACH_TYPE_NET5BIG_V2)
#else
# define machine_is_net5big_v2()	(0)
#endif

#ifdef CONFIG_MACH_INETSPACE_V2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INETSPACE_V2
# endif
# define machine_is_inetspace_v2()	(machine_arch_type == MACH_TYPE_INETSPACE_V2)
#else
# define machine_is_inetspace_v2()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9G45EKES
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9G45EKES
# endif
# define machine_is_at91sam9g45ekes()	(machine_arch_type == MACH_TYPE_AT91SAM9G45EKES)
#else
# define machine_is_at91sam9g45ekes()	(0)
#endif

#ifdef CONFIG_MACH_SPEAR600
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPEAR600
# endif
# define machine_is_spear600()	(machine_arch_type == MACH_TYPE_SPEAR600)
#else
# define machine_is_spear600()	(0)
#endif

#ifdef CONFIG_MACH_SPEAR300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPEAR300
# endif
# define machine_is_spear300()	(machine_arch_type == MACH_TYPE_SPEAR300)
#else
# define machine_is_spear300()	(0)
#endif

#ifdef CONFIG_MACH_LILLY1131
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LILLY1131
# endif
# define machine_is_lilly1131()	(machine_arch_type == MACH_TYPE_LILLY1131)
#else
# define machine_is_lilly1131()	(0)
#endif

#ifdef CONFIG_MACH_HMT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HMT
# endif
# define machine_is_hmt()	(machine_arch_type == MACH_TYPE_HMT)
#else
# define machine_is_hmt()	(0)
#endif

#ifdef CONFIG_MACH_VEXPRESS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VEXPRESS
# endif
# define machine_is_vexpress()	(machine_arch_type == MACH_TYPE_VEXPRESS)
#else
# define machine_is_vexpress()	(0)
#endif

#ifdef CONFIG_MACH_D2NET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_D2NET
# endif
# define machine_is_d2net()	(machine_arch_type == MACH_TYPE_D2NET)
#else
# define machine_is_d2net()	(0)
#endif

#ifdef CONFIG_MACH_BIGDISK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BIGDISK
# endif
# define machine_is_bigdisk()	(machine_arch_type == MACH_TYPE_BIGDISK)
#else
# define machine_is_bigdisk()	(0)
#endif

#ifdef CONFIG_MACH_AT91SAM9G20EK_2MMC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91SAM9G20EK_2MMC
# endif
# define machine_is_at91sam9g20ek_2mmc()	(machine_arch_type == MACH_TYPE_AT91SAM9G20EK_2MMC)
#else
# define machine_is_at91sam9g20ek_2mmc()	(0)
#endif

#ifdef CONFIG_MACH_BCMRING
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BCMRING
# endif
# define machine_is_bcmring()	(machine_arch_type == MACH_TYPE_BCMRING)
#else
# define machine_is_bcmring()	(0)
#endif

#ifdef CONFIG_MACH_MAHIMAHI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MAHIMAHI
# endif
# define machine_is_mahimahi()	(machine_arch_type == MACH_TYPE_MAHIMAHI)
#else
# define machine_is_mahimahi()	(0)
#endif

#ifdef CONFIG_MACH_SMDK6442
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK6442
# endif
# define machine_is_smdk6442()	(machine_arch_type == MACH_TYPE_SMDK6442)
#else
# define machine_is_smdk6442()	(0)
#endif

#ifdef CONFIG_MACH_OPENRD_BASE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OPENRD_BASE
# endif
# define machine_is_openrd_base()	(machine_arch_type == MACH_TYPE_OPENRD_BASE)
#else
# define machine_is_openrd_base()	(0)
#endif

#ifdef CONFIG_MACH_DEVKIT8000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DEVKIT8000
# endif
# define machine_is_devkit8000()	(machine_arch_type == MACH_TYPE_DEVKIT8000)
#else
# define machine_is_devkit8000()	(0)
#endif

#ifdef CONFIG_MACH_MX51_EFIKAMX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX51_EFIKAMX
# endif
# define machine_is_mx51_efikamx()	(machine_arch_type == MACH_TYPE_MX51_EFIKAMX)
#else
# define machine_is_mx51_efikamx()	(0)
#endif

#ifdef CONFIG_MACH_CM_T35
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM_T35
# endif
# define machine_is_cm_t35()	(machine_arch_type == MACH_TYPE_CM_T35)
#else
# define machine_is_cm_t35()	(0)
#endif

#ifdef CONFIG_MACH_NET2BIG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NET2BIG
# endif
# define machine_is_net2big()	(machine_arch_type == MACH_TYPE_NET2BIG)
#else
# define machine_is_net2big()	(0)
#endif

#ifdef CONFIG_MACH_IGEP0020
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IGEP0020
# endif
# define machine_is_igep0020()	(machine_arch_type == MACH_TYPE_IGEP0020)
#else
# define machine_is_igep0020()	(0)
#endif

#ifdef CONFIG_MACH_NUC932EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NUC932EVB
# endif
# define machine_is_nuc932evb()	(machine_arch_type == MACH_TYPE_NUC932EVB)
#else
# define machine_is_nuc932evb()	(0)
#endif

#ifdef CONFIG_MACH_OPENRD_CLIENT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OPENRD_CLIENT
# endif
# define machine_is_openrd_client()	(machine_arch_type == MACH_TYPE_OPENRD_CLIENT)
#else
# define machine_is_openrd_client()	(0)
#endif

#ifdef CONFIG_MACH_U8500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_U8500
# endif
# define machine_is_u8500()	(machine_arch_type == MACH_TYPE_U8500)
#else
# define machine_is_u8500()	(0)
#endif

#ifdef CONFIG_MACH_MX51_EFIKASB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX51_EFIKASB
# endif
# define machine_is_mx51_efikasb()	(machine_arch_type == MACH_TYPE_MX51_EFIKASB)
#else
# define machine_is_mx51_efikasb()	(0)
#endif

#ifdef CONFIG_MACH_MARVELL_JASPER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MARVELL_JASPER
# endif
# define machine_is_marvell_jasper()	(machine_arch_type == MACH_TYPE_MARVELL_JASPER)
#else
# define machine_is_marvell_jasper()	(0)
#endif

#ifdef CONFIG_MACH_FLINT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FLINT
# endif
# define machine_is_flint()	(machine_arch_type == MACH_TYPE_FLINT)
#else
# define machine_is_flint()	(0)
#endif

#ifdef CONFIG_MACH_TAVOREVB3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TAVOREVB3
# endif
# define machine_is_tavorevb3()	(machine_arch_type == MACH_TYPE_TAVOREVB3)
#else
# define machine_is_tavorevb3()	(0)
#endif

#ifdef CONFIG_MACH_TOUCHBOOK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TOUCHBOOK
# endif
# define machine_is_touchbook()	(machine_arch_type == MACH_TYPE_TOUCHBOOK)
#else
# define machine_is_touchbook()	(0)
#endif

#ifdef CONFIG_MACH_RAUMFELD_RC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RAUMFELD_RC
# endif
# define machine_is_raumfeld_rc()	(machine_arch_type == MACH_TYPE_RAUMFELD_RC)
#else
# define machine_is_raumfeld_rc()	(0)
#endif

#ifdef CONFIG_MACH_RAUMFELD_CONNECTOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RAUMFELD_CONNECTOR
# endif
# define machine_is_raumfeld_connector()	(machine_arch_type == MACH_TYPE_RAUMFELD_CONNECTOR)
#else
# define machine_is_raumfeld_connector()	(0)
#endif

#ifdef CONFIG_MACH_RAUMFELD_SPEAKER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RAUMFELD_SPEAKER
# endif
# define machine_is_raumfeld_speaker()	(machine_arch_type == MACH_TYPE_RAUMFELD_SPEAKER)
#else
# define machine_is_raumfeld_speaker()	(0)
#endif

#ifdef CONFIG_MACH_TNETV107X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TNETV107X
# endif
# define machine_is_tnetv107x()	(machine_arch_type == MACH_TYPE_TNETV107X)
#else
# define machine_is_tnetv107x()	(0)
#endif

#ifdef CONFIG_MACH_SMDKV210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDKV210
# endif
# define machine_is_smdkv210()	(machine_arch_type == MACH_TYPE_SMDKV210)
#else
# define machine_is_smdkv210()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_ZOOM3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_ZOOM3
# endif
# define machine_is_omap_zoom3()	(machine_arch_type == MACH_TYPE_OMAP_ZOOM3)
#else
# define machine_is_omap_zoom3()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_3630SDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_3630SDP
# endif
# define machine_is_omap_3630sdp()	(machine_arch_type == MACH_TYPE_OMAP_3630SDP)
#else
# define machine_is_omap_3630sdp()	(0)
#endif

#ifdef CONFIG_MACH_SMARTQ7
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMARTQ7
# endif
# define machine_is_smartq7()	(machine_arch_type == MACH_TYPE_SMARTQ7)
#else
# define machine_is_smartq7()	(0)
#endif

#ifdef CONFIG_MACH_G4EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_G4EVM
# endif
# define machine_is_g4evm()	(machine_arch_type == MACH_TYPE_G4EVM)
#else
# define machine_is_g4evm()	(0)
#endif

#ifdef CONFIG_MACH_OMAPL138_HAWKBOARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAPL138_HAWKBOARD
# endif
# define machine_is_omapl138_hawkboard()	(machine_arch_type == MACH_TYPE_OMAPL138_HAWKBOARD)
#else
# define machine_is_omapl138_hawkboard()	(0)
#endif

#ifdef CONFIG_MACH_TS41X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TS41X
# endif
# define machine_is_ts41x()	(machine_arch_type == MACH_TYPE_TS41X)
#else
# define machine_is_ts41x()	(0)
#endif

#ifdef CONFIG_MACH_PHY3250
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PHY3250
# endif
# define machine_is_phy3250()	(machine_arch_type == MACH_TYPE_PHY3250)
#else
# define machine_is_phy3250()	(0)
#endif

#ifdef CONFIG_MACH_MINI6410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MINI6410
# endif
# define machine_is_mini6410()	(machine_arch_type == MACH_TYPE_MINI6410)
#else
# define machine_is_mini6410()	(0)
#endif

#ifdef CONFIG_MACH_MX28EVK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX28EVK
# endif
# define machine_is_mx28evk()	(machine_arch_type == MACH_TYPE_MX28EVK)
#else
# define machine_is_mx28evk()	(0)
#endif

#ifdef CONFIG_MACH_SMARTQ5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMARTQ5
# endif
# define machine_is_smartq5()	(machine_arch_type == MACH_TYPE_SMARTQ5)
#else
# define machine_is_smartq5()	(0)
#endif

#ifdef CONFIG_MACH_DAVINCI_DM6467TEVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAVINCI_DM6467TEVM
# endif
# define machine_is_davinci_dm6467tevm()	(machine_arch_type == MACH_TYPE_DAVINCI_DM6467TEVM)
#else
# define machine_is_davinci_dm6467tevm()	(0)
#endif

#ifdef CONFIG_MACH_MXT_TD60
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MXT_TD60
# endif
# define machine_is_mxt_td60()	(machine_arch_type == MACH_TYPE_MXT_TD60)
#else
# define machine_is_mxt_td60()	(0)
#endif

#ifdef CONFIG_MACH_CAPC7117
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CAPC7117
# endif
# define machine_is_capc7117()	(machine_arch_type == MACH_TYPE_CAPC7117)
#else
# define machine_is_capc7117()	(0)
#endif

#ifdef CONFIG_MACH_ICONTROL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ICONTROL
# endif
# define machine_is_icontrol()	(machine_arch_type == MACH_TYPE_ICONTROL)
#else
# define machine_is_icontrol()	(0)
#endif

#ifdef CONFIG_MACH_GPLUGD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GPLUGD
# endif
# define machine_is_gplugd()	(machine_arch_type == MACH_TYPE_GPLUGD)
#else
# define machine_is_gplugd()	(0)
#endif

#ifdef CONFIG_MACH_QSD8X50A_ST1_5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QSD8X50A_ST1_5
# endif
# define machine_is_qsd8x50a_st1_5()	(machine_arch_type == MACH_TYPE_QSD8X50A_ST1_5)
#else
# define machine_is_qsd8x50a_st1_5()	(0)
#endif

#ifdef CONFIG_MACH_MX23EVK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX23EVK
# endif
# define machine_is_mx23evk()	(machine_arch_type == MACH_TYPE_MX23EVK)
#else
# define machine_is_mx23evk()	(0)
#endif

#ifdef CONFIG_MACH_AP4EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AP4EVB
# endif
# define machine_is_ap4evb()	(machine_arch_type == MACH_TYPE_AP4EVB)
#else
# define machine_is_ap4evb()	(0)
#endif

#ifdef CONFIG_MACH_MITYOMAPL138
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MITYOMAPL138
# endif
# define machine_is_mityomapl138()	(machine_arch_type == MACH_TYPE_MITYOMAPL138)
#else
# define machine_is_mityomapl138()	(0)
#endif

#ifdef CONFIG_MACH_GURUPLUG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GURUPLUG
# endif
# define machine_is_guruplug()	(machine_arch_type == MACH_TYPE_GURUPLUG)
#else
# define machine_is_guruplug()	(0)
#endif

#ifdef CONFIG_MACH_SPEAR310
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPEAR310
# endif
# define machine_is_spear310()	(machine_arch_type == MACH_TYPE_SPEAR310)
#else
# define machine_is_spear310()	(0)
#endif

#ifdef CONFIG_MACH_SPEAR320
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPEAR320
# endif
# define machine_is_spear320()	(machine_arch_type == MACH_TYPE_SPEAR320)
#else
# define machine_is_spear320()	(0)
#endif

#ifdef CONFIG_MACH_AQUILA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AQUILA
# endif
# define machine_is_aquila()	(machine_arch_type == MACH_TYPE_AQUILA)
#else
# define machine_is_aquila()	(0)
#endif

#ifdef CONFIG_MACH_ESATA_SHEEVAPLUG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESATA_SHEEVAPLUG
# endif
# define machine_is_esata_sheevaplug()	(machine_arch_type == MACH_TYPE_ESATA_SHEEVAPLUG)
#else
# define machine_is_esata_sheevaplug()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X30_SURF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X30_SURF
# endif
# define machine_is_msm7x30_surf()	(machine_arch_type == MACH_TYPE_MSM7X30_SURF)
#else
# define machine_is_msm7x30_surf()	(0)
#endif

#ifdef CONFIG_MACH_TERASTATION_WXL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TERASTATION_WXL
# endif
# define machine_is_terastation_wxl()	(machine_arch_type == MACH_TYPE_TERASTATION_WXL)
#else
# define machine_is_terastation_wxl()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X25_SURF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X25_SURF
# endif
# define machine_is_msm7x25_surf()	(machine_arch_type == MACH_TYPE_MSM7X25_SURF)
#else
# define machine_is_msm7x25_surf()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X25_FFA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X25_FFA
# endif
# define machine_is_msm7x25_ffa()	(machine_arch_type == MACH_TYPE_MSM7X25_FFA)
#else
# define machine_is_msm7x25_ffa()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X27_SURF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X27_SURF
# endif
# define machine_is_msm7x27_surf()	(machine_arch_type == MACH_TYPE_MSM7X27_SURF)
#else
# define machine_is_msm7x27_surf()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X27_FFA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X27_FFA
# endif
# define machine_is_msm7x27_ffa()	(machine_arch_type == MACH_TYPE_MSM7X27_FFA)
#else
# define machine_is_msm7x27_ffa()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X30_FFA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X30_FFA
# endif
# define machine_is_msm7x30_ffa()	(machine_arch_type == MACH_TYPE_MSM7X30_FFA)
#else
# define machine_is_msm7x30_ffa()	(0)
#endif

#ifdef CONFIG_MACH_QSD8X50_SURF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QSD8X50_SURF
# endif
# define machine_is_qsd8x50_surf()	(machine_arch_type == MACH_TYPE_QSD8X50_SURF)
#else
# define machine_is_qsd8x50_surf()	(0)
#endif

#ifdef CONFIG_MACH_MX53_EVK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX53_EVK
# endif
# define machine_is_mx53_evk()	(machine_arch_type == MACH_TYPE_MX53_EVK)
#else
# define machine_is_mx53_evk()	(0)
#endif

#ifdef CONFIG_MACH_IGEP0030
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IGEP0030
# endif
# define machine_is_igep0030()	(machine_arch_type == MACH_TYPE_IGEP0030)
#else
# define machine_is_igep0030()	(0)
#endif

#ifdef CONFIG_MACH_SBC3530
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SBC3530
# endif
# define machine_is_sbc3530()	(machine_arch_type == MACH_TYPE_SBC3530)
#else
# define machine_is_sbc3530()	(0)
#endif

#ifdef CONFIG_MACH_SAARB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SAARB
# endif
# define machine_is_saarb()	(machine_arch_type == MACH_TYPE_SAARB)
#else
# define machine_is_saarb()	(0)
#endif

#ifdef CONFIG_MACH_HARMONY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HARMONY
# endif
# define machine_is_harmony()	(machine_arch_type == MACH_TYPE_HARMONY)
#else
# define machine_is_harmony()	(0)
#endif

#ifdef CONFIG_MACH_MSM7X30_FLUID
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM7X30_FLUID
# endif
# define machine_is_msm7x30_fluid()	(machine_arch_type == MACH_TYPE_MSM7X30_FLUID)
#else
# define machine_is_msm7x30_fluid()	(0)
#endif

#ifdef CONFIG_MACH_CM_T3517
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM_T3517
# endif
# define machine_is_cm_t3517()	(machine_arch_type == MACH_TYPE_CM_T3517)
#else
# define machine_is_cm_t3517()	(0)
#endif

#ifdef CONFIG_MACH_WBD222
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WBD222
# endif
# define machine_is_wbd222()	(machine_arch_type == MACH_TYPE_WBD222)
#else
# define machine_is_wbd222()	(0)
#endif

#ifdef CONFIG_MACH_MSM8X60_SURF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM8X60_SURF
# endif
# define machine_is_msm8x60_surf()	(machine_arch_type == MACH_TYPE_MSM8X60_SURF)
#else
# define machine_is_msm8x60_surf()	(0)
#endif

#ifdef CONFIG_MACH_MSM8X60_SIM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM8X60_SIM
# endif
# define machine_is_msm8x60_sim()	(machine_arch_type == MACH_TYPE_MSM8X60_SIM)
#else
# define machine_is_msm8x60_sim()	(0)
#endif

#ifdef CONFIG_MACH_TCC8000_SDK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TCC8000_SDK
# endif
# define machine_is_tcc8000_sdk()	(machine_arch_type == MACH_TYPE_TCC8000_SDK)
#else
# define machine_is_tcc8000_sdk()	(0)
#endif

#ifdef CONFIG_MACH_CNS3420VB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CNS3420VB
# endif
# define machine_is_cns3420vb()	(machine_arch_type == MACH_TYPE_CNS3420VB)
#else
# define machine_is_cns3420vb()	(0)
#endif

#ifdef CONFIG_MACH_OMAP4_PANDA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP4_PANDA
# endif
# define machine_is_omap4_panda()	(machine_arch_type == MACH_TYPE_OMAP4_PANDA)
#else
# define machine_is_omap4_panda()	(0)
#endif

#ifdef CONFIG_MACH_TI8168EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TI8168EVM
# endif
# define machine_is_ti8168evm()	(machine_arch_type == MACH_TYPE_TI8168EVM)
#else
# define machine_is_ti8168evm()	(0)
#endif

#ifdef CONFIG_MACH_TETON_BGA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TETON_BGA
# endif
# define machine_is_teton_bga()	(machine_arch_type == MACH_TYPE_TETON_BGA)
#else
# define machine_is_teton_bga()	(0)
#endif

#ifdef CONFIG_MACH_EUKREA_CPUIMX25SD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EUKREA_CPUIMX25SD
# endif
# define machine_is_eukrea_cpuimx25sd()	(machine_arch_type == MACH_TYPE_EUKREA_CPUIMX25SD)
#else
# define machine_is_eukrea_cpuimx25sd()	(0)
#endif

#ifdef CONFIG_MACH_EUKREA_CPUIMX35SD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EUKREA_CPUIMX35SD
# endif
# define machine_is_eukrea_cpuimx35sd()	(machine_arch_type == MACH_TYPE_EUKREA_CPUIMX35SD)
#else
# define machine_is_eukrea_cpuimx35sd()	(0)
#endif

#ifdef CONFIG_MACH_EUKREA_CPUIMX51SD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EUKREA_CPUIMX51SD
# endif
# define machine_is_eukrea_cpuimx51sd()	(machine_arch_type == MACH_TYPE_EUKREA_CPUIMX51SD)
#else
# define machine_is_eukrea_cpuimx51sd()	(0)
#endif

#ifdef CONFIG_MACH_EUKREA_CPUIMX51
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EUKREA_CPUIMX51
# endif
# define machine_is_eukrea_cpuimx51()	(machine_arch_type == MACH_TYPE_EUKREA_CPUIMX51)
#else
# define machine_is_eukrea_cpuimx51()	(0)
#endif

#ifdef CONFIG_MACH_SMDKC210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDKC210
# endif
# define machine_is_smdkc210()	(machine_arch_type == MACH_TYPE_SMDKC210)
#else
# define machine_is_smdkc210()	(0)
#endif

#ifdef CONFIG_MACH_T5325
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_T5325
# endif
# define machine_is_t5325()	(machine_arch_type == MACH_TYPE_T5325)
#else
# define machine_is_t5325()	(0)
#endif

#ifdef CONFIG_MACH_INCOME
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INCOME
# endif
# define machine_is_income()	(machine_arch_type == MACH_TYPE_INCOME)
#else
# define machine_is_income()	(0)
#endif

#ifdef CONFIG_MACH_MESON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MESON
# endif
# define machine_is_meson()	(machine_arch_type == MACH_TYPE_MESON)
#else
# define machine_is_meson()	(0)
#endif

#ifdef CONFIG_MACH_GONI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GONI
# endif
# define machine_is_goni()	(machine_arch_type == MACH_TYPE_GONI)
#else
# define machine_is_goni()	(0)
#endif

#ifdef CONFIG_MACH_BV07
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BV07
# endif
# define machine_is_bv07()	(machine_arch_type == MACH_TYPE_BV07)
#else
# define machine_is_bv07()	(0)
#endif

#ifdef CONFIG_MACH_OPENRD_ULTIMATE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OPENRD_ULTIMATE
# endif
# define machine_is_openrd_ultimate()	(machine_arch_type == MACH_TYPE_OPENRD_ULTIMATE)
#else
# define machine_is_openrd_ultimate()	(0)
#endif

#ifdef CONFIG_MACH_DEVIXP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DEVIXP
# endif
# define machine_is_devixp()	(machine_arch_type == MACH_TYPE_DEVIXP)
#else
# define machine_is_devixp()	(0)
#endif

#ifdef CONFIG_MACH_MICCPT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MICCPT
# endif
# define machine_is_miccpt()	(machine_arch_type == MACH_TYPE_MICCPT)
#else
# define machine_is_miccpt()	(0)
#endif

#ifdef CONFIG_MACH_MIC256
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MIC256
# endif
# define machine_is_mic256()	(machine_arch_type == MACH_TYPE_MIC256)
#else
# define machine_is_mic256()	(0)
#endif

#ifdef CONFIG_MACH_U5500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_U5500
# endif
# define machine_is_u5500()	(machine_arch_type == MACH_TYPE_U5500)
#else
# define machine_is_u5500()	(0)
#endif

#ifdef CONFIG_MACH_LINKSTATION_LSCHL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LINKSTATION_LSCHL
# endif
# define machine_is_linkstation_lschl()	(machine_arch_type == MACH_TYPE_LINKSTATION_LSCHL)
#else
# define machine_is_linkstation_lschl()	(0)
#endif

#ifdef CONFIG_MACH_SMDKV310
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDKV310
# endif
# define machine_is_smdkv310()	(machine_arch_type == MACH_TYPE_SMDKV310)
#else
# define machine_is_smdkv310()	(0)
#endif

#ifdef CONFIG_MACH_WM8505_7IN_NETBOOK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WM8505_7IN_NETBOOK
# endif
# define machine_is_wm8505_7in_netbook()	(machine_arch_type == MACH_TYPE_WM8505_7IN_NETBOOK)
#else
# define machine_is_wm8505_7in_netbook()	(0)
#endif

#ifdef CONFIG_MACH_CRANEBOARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CRANEBOARD
# endif
# define machine_is_craneboard()	(machine_arch_type == MACH_TYPE_CRANEBOARD)
#else
# define machine_is_craneboard()	(0)
#endif

#ifdef CONFIG_MACH_SMDK6450
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK6450
# endif
# define machine_is_smdk6450()	(machine_arch_type == MACH_TYPE_SMDK6450)
#else
# define machine_is_smdk6450()	(0)
#endif

#ifdef CONFIG_MACH_BROWNSTONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BROWNSTONE
# endif
# define machine_is_brownstone()	(machine_arch_type == MACH_TYPE_BROWNSTONE)
#else
# define machine_is_brownstone()	(0)
#endif

#ifdef CONFIG_MACH_FLEXIBITY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FLEXIBITY
# endif
# define machine_is_flexibity()	(machine_arch_type == MACH_TYPE_FLEXIBITY)
#else
# define machine_is_flexibity()	(0)
#endif

#ifdef CONFIG_MACH_MX50_RDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX50_RDP
# endif
# define machine_is_mx50_rdp()	(machine_arch_type == MACH_TYPE_MX50_RDP)
#else
# define machine_is_mx50_rdp()	(0)
#endif

#ifdef CONFIG_MACH_UNIVERSAL_C210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_UNIVERSAL_C210
# endif
# define machine_is_universal_c210()	(machine_arch_type == MACH_TYPE_UNIVERSAL_C210)
#else
# define machine_is_universal_c210()	(0)
#endif

#ifdef CONFIG_MACH_REAL6410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REAL6410
# endif
# define machine_is_real6410()	(machine_arch_type == MACH_TYPE_REAL6410)
#else
# define machine_is_real6410()	(0)
#endif

#ifdef CONFIG_MACH_DOCKSTAR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DOCKSTAR
# endif
# define machine_is_dockstar()	(machine_arch_type == MACH_TYPE_DOCKSTAR)
#else
# define machine_is_dockstar()	(0)
#endif

#ifdef CONFIG_MACH_TI8148EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TI8148EVM
# endif
# define machine_is_ti8148evm()	(machine_arch_type == MACH_TYPE_TI8148EVM)
#else
# define machine_is_ti8148evm()	(0)
#endif

#ifdef CONFIG_MACH_SEABOARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SEABOARD
# endif
# define machine_is_seaboard()	(machine_arch_type == MACH_TYPE_SEABOARD)
#else
# define machine_is_seaboard()	(0)
#endif

#ifdef CONFIG_MACH_MX53_ARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX53_ARD
# endif
# define machine_is_mx53_ard()	(machine_arch_type == MACH_TYPE_MX53_ARD)
#else
# define machine_is_mx53_ard()	(0)
#endif

#ifdef CONFIG_MACH_MX53_SMD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX53_SMD
# endif
# define machine_is_mx53_smd()	(machine_arch_type == MACH_TYPE_MX53_SMD)
#else
# define machine_is_mx53_smd()	(0)
#endif

#ifdef CONFIG_MACH_MSM8X60_RUMI3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM8X60_RUMI3
# endif
# define machine_is_msm8x60_rumi3()	(machine_arch_type == MACH_TYPE_MSM8X60_RUMI3)
#else
# define machine_is_msm8x60_rumi3()	(0)
#endif

#ifdef CONFIG_MACH_MSM8X60_FFA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM8X60_FFA
# endif
# define machine_is_msm8x60_ffa()	(machine_arch_type == MACH_TYPE_MSM8X60_FFA)
#else
# define machine_is_msm8x60_ffa()	(0)
#endif

#ifdef CONFIG_MACH_CM_A510
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM_A510
# endif
# define machine_is_cm_a510()	(machine_arch_type == MACH_TYPE_CM_A510)
#else
# define machine_is_cm_a510()	(0)
#endif

#ifdef CONFIG_MACH_TX28
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TX28
# endif
# define machine_is_tx28()	(machine_arch_type == MACH_TYPE_TX28)
#else
# define machine_is_tx28()	(0)
#endif

#ifdef CONFIG_MACH_PCONTROL_G20
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCONTROL_G20
# endif
# define machine_is_pcontrol_g20()	(machine_arch_type == MACH_TYPE_PCONTROL_G20)
#else
# define machine_is_pcontrol_g20()	(0)
#endif

#ifdef CONFIG_MACH_VPR200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VPR200
# endif
# define machine_is_vpr200()	(machine_arch_type == MACH_TYPE_VPR200)
#else
# define machine_is_vpr200()	(0)
#endif

#ifdef CONFIG_MACH_TORBRECK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TORBRECK
# endif
# define machine_is_torbreck()	(machine_arch_type == MACH_TYPE_TORBRECK)
#else
# define machine_is_torbreck()	(0)
#endif

#ifdef CONFIG_MACH_PRIMA2_EVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PRIMA2_EVB
# endif
# define machine_is_prima2_evb()	(machine_arch_type == MACH_TYPE_PRIMA2_EVB)
#else
# define machine_is_prima2_evb()	(0)
#endif

#ifdef CONFIG_MACH_PAZ00
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PAZ00
# endif
# define machine_is_paz00()	(machine_arch_type == MACH_TYPE_PAZ00)
#else
# define machine_is_paz00()	(0)
#endif

#ifdef CONFIG_MACH_ACMENETUSFOXG20
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACMENETUSFOXG20
# endif
# define machine_is_acmenetusfoxg20()	(machine_arch_type == MACH_TYPE_ACMENETUSFOXG20)
#else
# define machine_is_acmenetusfoxg20()	(0)
#endif

#ifdef CONFIG_MACH_AG5EVM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AG5EVM
# endif
# define machine_is_ag5evm()	(machine_arch_type == MACH_TYPE_AG5EVM)
#else
# define machine_is_ag5evm()	(0)
#endif

#ifdef CONFIG_MACH_WLF_CRAGG_6410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WLF_CRAGG_6410
# endif
# define machine_is_wlf_cragg_6410()	(machine_arch_type == MACH_TYPE_WLF_CRAGG_6410)
#else
# define machine_is_wlf_cragg_6410()	(0)
#endif

#ifdef CONFIG_MACH_TRIMSLICE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TRIMSLICE
# endif
# define machine_is_trimslice()	(machine_arch_type == MACH_TYPE_TRIMSLICE)
#else
# define machine_is_trimslice()	(0)
#endif

#ifdef CONFIG_MACH_MACKEREL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MACKEREL
# endif
# define machine_is_mackerel()	(machine_arch_type == MACH_TYPE_MACKEREL)
#else
# define machine_is_mackerel()	(0)
#endif

#ifdef CONFIG_MACH_KAEN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KAEN
# endif
# define machine_is_kaen()	(machine_arch_type == MACH_TYPE_KAEN)
#else
# define machine_is_kaen()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA_RM680
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA_RM680
# endif
# define machine_is_nokia_rm680()	(machine_arch_type == MACH_TYPE_NOKIA_RM680)
#else
# define machine_is_nokia_rm680()	(0)
#endif

#ifdef CONFIG_MACH_MSM8960_SIM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM8960_SIM
# endif
# define machine_is_msm8960_sim()	(machine_arch_type == MACH_TYPE_MSM8960_SIM)
#else
# define machine_is_msm8960_sim()	(0)
#endif

#ifdef CONFIG_MACH_MSM8960_RUMI3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSM8960_RUMI3
# endif
# define machine_is_msm8960_rumi3()	(machine_arch_type == MACH_TYPE_MSM8960_RUMI3)
#else
# define machine_is_msm8960_rumi3()	(0)
#endif

#ifdef CONFIG_MACH_GSIA18S
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GSIA18S
# endif
# define machine_is_gsia18s()	(machine_arch_type == MACH_TYPE_GSIA18S)
#else
# define machine_is_gsia18s()	(0)
#endif

#ifdef CONFIG_MACH_MX53_LOCO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX53_LOCO
# endif
# define machine_is_mx53_loco()	(machine_arch_type == MACH_TYPE_MX53_LOCO)
#else
# define machine_is_mx53_loco()	(0)
#endif

#ifdef CONFIG_MACH_WARIO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WARIO
# endif
# define machine_is_wario()	(machine_arch_type == MACH_TYPE_WARIO)
#else
# define machine_is_wario()	(0)
#endif

#ifdef CONFIG_MACH_CM_T3730
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM_T3730
# endif
# define machine_is_cm_t3730()	(machine_arch_type == MACH_TYPE_CM_T3730)
#else
# define machine_is_cm_t3730()	(0)
#endif

#ifdef CONFIG_MACH_HREFV60
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HREFV60
# endif
# define machine_is_hrefv60()	(machine_arch_type == MACH_TYPE_HREFV60)
#else
# define machine_is_hrefv60()	(0)
#endif

#ifdef CONFIG_MACH_ARMLEX4210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMLEX4210
# endif
# define machine_is_armlex4210()	(machine_arch_type == MACH_TYPE_ARMLEX4210)
#else
# define machine_is_armlex4210()	(0)
#endif

#ifdef CONFIG_MACH_SNOWBALL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SNOWBALL
# endif
# define machine_is_snowball()	(machine_arch_type == MACH_TYPE_SNOWBALL)
#else
# define machine_is_snowball()	(0)
#endif

#ifdef CONFIG_MACH_XILINX_EP107
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XILINX_EP107
# endif
# define machine_is_xilinx_ep107()	(machine_arch_type == MACH_TYPE_XILINX_EP107)
#else
# define machine_is_xilinx_ep107()	(0)
#endif

#ifdef CONFIG_MACH_NURI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NURI
# endif
# define machine_is_nuri()	(machine_arch_type == MACH_TYPE_NURI)
#else
# define machine_is_nuri()	(0)
#endif

#ifdef CONFIG_MACH_ORIGEN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ORIGEN
# endif
# define machine_is_origen()	(machine_arch_type == MACH_TYPE_ORIGEN)
#else
# define machine_is_origen()	(0)
#endif

#ifdef CONFIG_MACH_XARINA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XARINA
# endif
# define machine_is_xarina()	(machine_arch_type == MACH_TYPE_XARINA)
#else
# define machine_is_xarina()	(0)
#endif

#ifdef CONFIG_MACH_NSPIRE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NSPIRE
# endif
# define machine_is_nspire()	(machine_arch_type == MACH_TYPE_NSPIRE)
#else
# define machine_is_nspire()	(0)
#endif

#ifdef CONFIG_MACH_NOKIA_RM696
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOKIA_RM696
# endif
# define machine_is_nokia_rm696()	(machine_arch_type == MACH_TYPE_NOKIA_RM696)
#else
# define machine_is_nokia_rm696()	(0)
#endif

#ifdef CONFIG_MACH_M28EVK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_M28EVK
# endif
# define machine_is_m28evk()	(machine_arch_type == MACH_TYPE_M28EVK)
#else
# define machine_is_m28evk()	(0)
#endif

#ifdef CONFIG_MACH_KOTA2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KOTA2
# endif
# define machine_is_kota2()	(machine_arch_type == MACH_TYPE_KOTA2)
#else
# define machine_is_kota2()	(0)
#endif

#ifdef CONFIG_MACH_BONITO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BONITO
# endif
# define machine_is_bonito()	(machine_arch_type == MACH_TYPE_BONITO)
#else
# define machine_is_bonito()	(0)
#endif

#ifdef CONFIG_MACH_SMDK4212
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK4212
# endif
# define machine_is_smdk4212()	(machine_arch_type == MACH_TYPE_SMDK4212)
#else
# define machine_is_smdk4212()	(0)
#endif

#ifdef CONFIG_MACH_APX4DEVKIT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_APX4DEVKIT
# endif
# define machine_is_apx4devkit()	(machine_arch_type == MACH_TYPE_APX4DEVKIT)
#else
# define machine_is_apx4devkit()	(0)
#endif

#ifdef CONFIG_MACH_SMDK4412
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK4412
# endif
# define machine_is_smdk4412()	(machine_arch_type == MACH_TYPE_SMDK4412)
#else
# define machine_is_smdk4412()	(0)
#endif

#ifdef CONFIG_MACH_MARZEN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MARZEN
# endif
# define machine_is_marzen()	(machine_arch_type == MACH_TYPE_MARZEN)
#else
# define machine_is_marzen()	(0)
#endif

#ifdef CONFIG_MACH_EMPC_A500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMPC_A500
# endif
# define machine_is_empc_a500()	(machine_arch_type == MACH_TYPE_EMPC_A500)
#else
# define machine_is_empc_a500()	(0)
#endif

#ifdef CONFIG_MACH_U8520
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_U8520
# endif
# define machine_is_u8520()	(machine_arch_type == MACH_TYPE_U8520)
#else
# define machine_is_u8520()	(0)
#endif

#ifdef CONFIG_MACH_URT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_URT
# endif
# define machine_is_urt()	(machine_arch_type == MACH_TYPE_URT)
#else
# define machine_is_urt()	(0)
#endif

#ifdef CONFIG_MACH_KEYSTONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KEYSTONE
# endif
# define machine_is_keystone()	(machine_arch_type == MACH_TYPE_KEYSTONE)
#else
# define machine_is_keystone()	(0)
#endif

#ifdef CONFIG_MACH_CKB_RZA1H
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CKB_RZA1H
# endif
# define machine_is_ckb_rza1h()	(machine_arch_type == MACH_TYPE_CKB_RZA1H)
#else
# define machine_is_ckb_rza1h()	(0)
#endif

#ifdef CONFIG_MACH_BCM2835
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BCM2835
# endif
# define machine_is_bcm2835()	(machine_arch_type == MACH_TYPE_BCM2835)
#else
# define machine_is_bcm2835()	(0)
#endif

#ifdef CONFIG_MACH_CM_3G
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CM_3G
# endif
# define machine_is_cm_3g()	(machine_arch_type == MACH_TYPE_CM_3G)
#else
# define machine_is_cm_3g()	(0)
#endif

#ifdef CONFIG_MACH_EMPC_AIMX6
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMPC_AIMX6
# endif
# define machine_is_empc_aimx6()	(machine_arch_type == MACH_TYPE_EMPC_AIMX6)
#else
# define machine_is_empc_aimx6()	(0)
#endif

#ifdef CONFIG_MACH_DIYEFIS6410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DIYEFIS6410
# endif
# define machine_is_diyefis6410()	(machine_arch_type == MACH_TYPE_DIYEFIS6410)
#else
# define machine_is_diyefis6410()	(0)
#endif

#ifdef CONFIG_MACH_MX53_TURING
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX53_TURING
# endif
# define machine_is_mx53_turing()	(machine_arch_type == MACH_TYPE_MX53_TURING)
#else
# define machine_is_mx53_turing()	(0)
#endif

#ifdef CONFIG_MACH_MX6DL_TURING
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX6DL_TURING
# endif
# define machine_is_mx6dl_turing()	(machine_arch_type == MACH_TYPE_MX6DL_TURING)
#else
# define machine_is_mx6dl_turing()	(0)
#endif

#ifdef CONFIG_MACH_MX53_INDASH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX53_INDASH
# endif
# define machine_is_mx53_indash()	(machine_arch_type == MACH_TYPE_MX53_INDASH)
#else
# define machine_is_mx53_indash()	(0)
#endif

#ifdef CONFIG_MACH_MX6Q_INDASH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX6Q_INDASH
# endif
# define machine_is_mx6q_indash()	(machine_arch_type == MACH_TYPE_MX6Q_INDASH)
#else
# define machine_is_mx6q_indash()	(0)
#endif

#ifdef CONFIG_MACH_MX6DL_INDASH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX6DL_INDASH
# endif
# define machine_is_mx6dl_indash()	(machine_arch_type == MACH_TYPE_MX6DL_INDASH)
#else
# define machine_is_mx6dl_indash()	(0)
#endif

#ifdef CONFIG_MACH_RTS_G6
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RTS_G6
# endif
# define machine_is_rts_g6()	(machine_arch_type == MACH_TYPE_RTS_G6)
#else
# define machine_is_rts_g6()	(0)
#endif

#ifdef CONFIG_MACH_KA_TITAN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KA_TITAN
# endif
# define machine_is_ka_titan()	(machine_arch_type == MACH_TYPE_KA_TITAN)
#else
# define machine_is_ka_titan()	(0)
#endif

#ifdef CONFIG_MACH_CL_SOM_IMX7
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CL_SOM_IMX7
# endif
# define machine_is_cl_som_imx7()	(machine_arch_type == MACH_TYPE_CL_SOM_IMX7)
#else
# define machine_is_cl_som_imx7()	(0)
#endif

#ifdef CONFIG_MACH_VVDN_MGSI_VSIS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VVDN_MGSI_VSIS
# endif
# define machine_is_vvdn_mgsi_vsis()	(machine_arch_type == MACH_TYPE_VVDN_MGSI_VSIS)
#else
# define machine_is_vvdn_mgsi_vsis()	(0)
#endif

#ifdef CONFIG_MACH_MX6Q_NANO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX6Q_NANO
# endif
# define machine_is_mx6q_nano()	(machine_arch_type == MACH_TYPE_MX6Q_NANO)
#else
# define machine_is_mx6q_nano()	(0)
#endif

#ifdef CONFIG_MACH_PDU001
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PDU001
# endif
# define machine_is_pdu001()	(machine_arch_type == MACH_TYPE_PDU001)
#else
# define machine_is_pdu001()	(0)
#endif

#ifdef CONFIG_MACH_CAB_PROYK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CAB_PROYK
# endif
# define machine_is_cab_proyk()	(machine_arch_type == MACH_TYPE_CAB_PROYK)
#else
# define machine_is_cab_proyk()	(0)
#endif

#ifdef CONFIG_MACH_KLIN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KLIN
# endif
# define machine_is_klin()	(machine_arch_type == MACH_TYPE_KLIN)
#else
# define machine_is_klin()	(0)
#endif

#ifdef CONFIG_MACH_ENMAN_STEUERBOX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ENMAN_STEUERBOX
# endif
# define machine_is_enman_steuerbox()	(machine_arch_type == MACH_TYPE_ENMAN_STEUERBOX)
#else
# define machine_is_enman_steuerbox()	(0)
#endif

#ifdef CONFIG_MACH_LS_STINGRAY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LS_STINGRAY
# endif
# define machine_is_ls_stingray()	(machine_arch_type == MACH_TYPE_LS_STINGRAY)
#else
# define machine_is_ls_stingray()	(0)
#endif

#ifdef CONFIG_MACH_IPDU
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IPDU
# endif
# define machine_is_ipdu()	(machine_arch_type == MACH_TYPE_IPDU)
#else
# define machine_is_ipdu()	(0)
#endif

#ifdef CONFIG_MACH_LINDA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LINDA
# endif
# define machine_is_linda()	(machine_arch_type == MACH_TYPE_LINDA)
#else
# define machine_is_linda()	(0)
#endif

#ifdef CONFIG_MACH_MX6Q_OPENREX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX6Q_OPENREX
# endif
# define machine_is_mx6q_openrex()	(machine_arch_type == MACH_TYPE_MX6Q_OPENREX)
#else
# define machine_is_mx6q_openrex()	(0)
#endif

#ifdef CONFIG_MACH_ON100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ON100
# endif
# define machine_is_on100()	(machine_arch_type == MACH_TYPE_ON100)
#else
# define machine_is_on100()	(0)
#endif

#ifdef CONFIG_MACH_EMINDS_RTU12
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMINDS_RTU12
# endif
# define machine_is_eminds_rtu12()	(machine_arch_type == MACH_TYPE_EMINDS_RTU12)
#else
# define machine_is_eminds_rtu12()	(0)
#endif

#ifdef CONFIG_MACH_EMINDS_AVL10
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMINDS_AVL10
# endif
# define machine_is_eminds_avl10()	(machine_arch_type == MACH_TYPE_EMINDS_AVL10)
#else
# define machine_is_eminds_avl10()	(0)
#endif

#ifdef CONFIG_MACH_MAIN_PLC_LME
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MAIN_PLC_LME
# endif
# define machine_is_main_plc_lme()	(machine_arch_type == MACH_TYPE_MAIN_PLC_LME)
#else
# define machine_is_main_plc_lme()	(0)
#endif

#ifdef CONFIG_MACH_MSPX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MSPX
# endif
# define machine_is_mspx()	(machine_arch_type == MACH_TYPE_MSPX)
#else
# define machine_is_mspx()	(0)
#endif

#ifdef CONFIG_MACH_CGW_300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CGW_300
# endif
# define machine_is_cgw_300()	(machine_arch_type == MACH_TYPE_CGW_300)
#else
# define machine_is_cgw_300()	(0)
#endif

#ifdef CONFIG_MACH_MX7D_CICADA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX7D_CICADA
# endif
# define machine_is_mx7d_cicada()	(machine_arch_type == MACH_TYPE_MX7D_CICADA)
#else
# define machine_is_mx7d_cicada()	(0)
#endif

#ifdef CONFIG_MACH_VIRT2REAL_DM365
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VIRT2REAL_DM365
# endif
# define machine_is_virt2real_dm365()	(machine_arch_type == MACH_TYPE_VIRT2REAL_DM365)
#else
# define machine_is_virt2real_dm365()	(0)
#endif

#ifdef CONFIG_MACH_DM365_VIRT2REAL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DM365_VIRT2REAL
# endif
# define machine_is_dm365_virt2real()	(machine_arch_type == MACH_TYPE_DM365_VIRT2REAL)
#else
# define machine_is_dm365_virt2real()	(0)
#endif

#ifdef CONFIG_MACH_H6073
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H6073
# endif
# define machine_is_h6073()	(machine_arch_type == MACH_TYPE_H6073)
#else
# define machine_is_h6073()	(0)
#endif

#ifdef CONFIG_MACH_GTGATEWAY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GTGATEWAY
# endif
# define machine_is_gtgateway()	(machine_arch_type == MACH_TYPE_GTGATEWAY)
#else
# define machine_is_gtgateway()	(0)
#endif

#ifdef CONFIG_MACH_XARINA_STANDARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XARINA_STANDARD
# endif
# define machine_is_xarina_standard()	(machine_arch_type == MACH_TYPE_XARINA_STANDARD)
#else
# define machine_is_xarina_standard()	(0)
#endif

#ifdef CONFIG_MACH_NOVASOMS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOVASOMS
# endif
# define machine_is_novasoms()	(machine_arch_type == MACH_TYPE_NOVASOMS)
#else
# define machine_is_novasoms()	(0)
#endif

#ifdef CONFIG_MACH_NOVASOMP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOVASOMP
# endif
# define machine_is_novasomp()	(machine_arch_type == MACH_TYPE_NOVASOMP)
#else
# define machine_is_novasomp()	(0)
#endif

#ifdef CONFIG_MACH_NOVASOMU
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOVASOMU
# endif
# define machine_is_novasomu()	(machine_arch_type == MACH_TYPE_NOVASOMU)
#else
# define machine_is_novasomu()	(0)
#endif

#ifdef CONFIG_MACH_MX6Q_MPBD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX6Q_MPBD
# endif
# define machine_is_mx6q_mpbd()	(machine_arch_type == MACH_TYPE_MX6Q_MPBD)
#else
# define machine_is_mx6q_mpbd()	(0)
#endif

#ifdef CONFIG_MACH_NCR_1930
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NCR_1930
# endif
# define machine_is_ncr_1930()	(machine_arch_type == MACH_TYPE_NCR_1930)
#else
# define machine_is_ncr_1930()	(0)
#endif

#ifdef CONFIG_MACH_UAP301
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_UAP301
# endif
# define machine_is_uap301()	(machine_arch_type == MACH_TYPE_UAP301)
#else
# define machine_is_uap301()	(0)
#endif

#ifdef CONFIG_MACH_URT02
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_URT02
# endif
# define machine_is_urt02()	(machine_arch_type == MACH_TYPE_URT02)
#else
# define machine_is_urt02()	(0)
#endif

#ifdef CONFIG_MACH_ATC8
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ATC8
# endif
# define machine_is_atc8()	(machine_arch_type == MACH_TYPE_ATC8)
#else
# define machine_is_atc8()	(0)
#endif

#ifdef CONFIG_MACH_IOT_GATEWAY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IOT_GATEWAY
# endif
# define machine_is_iot_gateway()	(machine_arch_type == MACH_TYPE_IOT_GATEWAY)
#else
# define machine_is_iot_gateway()	(0)
#endif

#ifdef CONFIG_MACH_HSM_PHOENIX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HSM_PHOENIX
# endif
# define machine_is_hsm_phoenix()	(machine_arch_type == MACH_TYPE_HSM_PHOENIX)
#else
# define machine_is_hsm_phoenix()	(0)
#endif

#ifdef CONFIG_MACH_MISSOURI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MISSOURI
# endif
# define machine_is_missouri()	(machine_arch_type == MACH_TYPE_MISSOURI)
#else
# define machine_is_missouri()	(0)
#endif

#ifdef CONFIG_MACH_REMARKABLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REMARKABLE
# endif
# define machine_is_remarkable()	(machine_arch_type == MACH_TYPE_REMARKABLE)
#else
# define machine_is_remarkable()	(0)
#endif

#ifdef CONFIG_MACH_FA0113
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FA0113
# endif
# define machine_is_fa0113()	(machine_arch_type == MACH_TYPE_FA0113)
#else
# define machine_is_fa0113()	(0)
#endif

#ifdef CONFIG_MACH_INNOVA_STATNETTAWM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INNOVA_STATNETTAWM
# endif
# define machine_is_innova_statnettawm()	(machine_arch_type == MACH_TYPE_INNOVA_STATNETTAWM)
#else
# define machine_is_innova_statnettawm()	(0)
#endif

/*
 * These have not yet been registered
 */

#ifndef machine_arch_type
#define machine_arch_type	__machine_arch_type
#endif

#endif
